pub unsafe extern "C" fn nvme_ctrl_find(
s: nvme_subsystem_t,
transport: *const c_char,
traddr: *const c_char,
trsvcid: *const c_char,
subsysnqn: *const c_char,
host_traddr: *const c_char,
host_iface: *const c_char,
) -> nvme_ctrl_tExpand description
nvme_ctrl_find() - Locate an existing controller @s: &nvme_subsystem_t object @transport: Transport name @traddr: Transport address @trsvcid: Transport service identifier @subsysnqn: Subsystem NQN @host_traddr: Host transport address @host_iface: Host interface name
Lookup a controller in @s based on @transport, @traddr, @trsvcid, @subsysnqn, @host_traddr, and @host_iface. @transport must be specified, other fields may be required depending on the transport. Parameters set to NULL will be ignored.
Unlike nvme_lookup_ctrl(), this function does not create a new object if an existing controller cannot be found.
Return: Controller instance on success, NULL otherwise.