pub unsafe extern "C" fn nvme_ctrl_release_fd(c: nvme_ctrl_t)Expand description
nvme_ctrl_release_fd() - Close fd and clear fd from controller object @c: Controller instance
pub unsafe extern "C" fn nvme_ctrl_release_fd(c: nvme_ctrl_t)nvme_ctrl_release_fd() - Close fd and clear fd from controller object @c: Controller instance