nvme_dev_self_test

Function nvme_dev_self_test 

pub unsafe extern "C" fn nvme_dev_self_test(
    args: *mut nvme_dev_self_test_args,
) -> c_int
nvme_dev_self_test() - Start or abort a self test @args: &struct nvme_dev_self_test argument structure

The Device Self-test command starts a device self-test operation or abort a device self-test operation. A device self-test operation is a diagnostic testing sequence that tests the integrity and functionality of the controller and may include testing of the media associated with namespaces. The controller may return a response to this command immediately while running the self-test in the background.

Set the ‘nsid’ field to 0 to not include namespaces in the test. Set to 0xffffffff to test all namespaces. All other values tests a specific namespace, if present.

Return: The nvme command status if a response was received (see &enum nvme_status_field) or -1 with errno set otherwise.