nvme_format_nvm

Function nvme_format_nvm 

pub unsafe extern "C" fn nvme_format_nvm(
    args: *mut nvme_format_nvm_args,
) -> c_int
nvme_format_nvm() - Format nvme namespace(s) @args: &struct nvme_format_nvme_args argument structure

The Format NVM command low level formats the NVM media. This command is used by the host to change the LBA data size and/or metadata size. A low level format may destroy all data and metadata associated with all namespaces or only the specific namespace associated with the command

Return: The nvme command status if a response was received (see &enum nvme_status_field) or -1 with errno set otherwise.