nvme_fw_commit

Function nvme_fw_commit 

pub unsafe extern "C" fn nvme_fw_commit(
    args: *mut nvme_fw_commit_args,
) -> c_int
nvme_fw_commit() - Commit firmware using the specified action @args: &struct nvme_fw_commit_args argument structure

The Firmware Commit command modifies the firmware image or Boot Partitions.

Return: The nvme command status if a response was received (see &enum nvme_status_field) or -1 with errno set otherwise. The command status response may specify additional reset actions required to complete the commit process.