nvme_get_features_temp_thresh2

Function nvme_get_features_temp_thresh2 

pub unsafe extern "C" fn nvme_get_features_temp_thresh2(
    fd: c_int,
    sel: nvme_get_features_sel,
    tmpsel: __u8,
    thsel: nvme_feat_tmpthresh_thsel,
    result: *mut __u32,
) -> c_int
nvme_get_features_temp_thresh2() - Get temperature threshold feature @fd: File descriptor of nvme device @sel: Select which type of attribute to return, see &enum nvme_get_features_sel @tmpsel: Threshold Temperature Select @thsel: Threshold Type Select @result: The command completion result from CQE dword0

Return: The nvme command status if a response was received (see &enum nvme_status_field) or -1 with errno set otherwise.