nvme_get_features_write_atomic

Function nvme_get_features_write_atomic 

pub unsafe extern "C" fn nvme_get_features_write_atomic(
    fd: c_int,
    sel: nvme_get_features_sel,
    result: *mut __u32,
) -> c_int
nvme_get_features_write_atomic() - Get write atomic feature @fd: File descriptor of nvme device @sel: Select which type of attribute to return, see &enum nvme_get_features_sel @result: The command completion result from CQE dword0

Return: The nvme command status if a response was received (see &enum nvme_status_field) or -1 with errno set otherwise.