nvme_get_features_write_protect

Function nvme_get_features_write_protect 

pub unsafe extern "C" fn nvme_get_features_write_protect(
    fd: c_int,
    nsid: __u32,
    sel: nvme_get_features_sel,
    result: *mut __u32,
) -> c_int
nvme_get_features_write_protect() - Get write protect feature @fd: File descriptor of nvme device @nsid: Namespace ID @sel: Select which type of attribute to return, see &enum nvme_get_features_sel @result: The command completion result from CQE dword0

Return: The nvme command status if a response was received (see &enum nvme_status_field) or -1 with errno set otherwise.