nvme_get_logging_level

Function nvme_get_logging_level 

pub unsafe extern "C" fn nvme_get_logging_level(
    r: nvme_root_t,
    log_pid: *mut bool,
    log_tstamp: *mut bool,
) -> c_int
nvme_get_logging_level() - Get current logging level @r: nvme_root_t context @log_pid: Pointer to store a current value of logging of the PID flag at (optional). @log_tstamp: Pointer to store a current value of logging of the timestamp flag at (optional).

Retrieves current values of logging variables.

Return: current log level value or DEFAULT_LOGLEVEL if not initialized.