nvme_host_set_pdc_enabled

Function nvme_host_set_pdc_enabled 

pub unsafe extern "C" fn nvme_host_set_pdc_enabled(
    h: nvme_host_t,
    enabled: bool,
)
nvme_host_set_pdc_enabled() - Set Persistent Discovery Controller flag @h: Host for which the falg should be set @enabled: The bool to set the enabled flag

When nvme_host_set_pdc_enabled() is not used to set the PDC flag, nvme_host_is_pdc_enabled() will return the default value which was passed into the function and not the undefined flag value.