nvme_identify

Function nvme_identify 

pub unsafe extern "C" fn nvme_identify(
    args: *mut nvme_identify_args,
) -> c_int
nvme_identify() - Send the NVMe Identify command @args: &struct nvme_identify_args argument structure

The Identify command returns a data buffer that describes information about the NVM subsystem, the controller or the namespace(s).

Return: The nvme command status if a response was received (see &enum nvme_status_field) or -1 with errno set otherwise.