nvme_open

Function nvme_open 

pub unsafe extern "C" fn nvme_open(name: *const c_char) -> c_int
nvme_open() - Open an nvme controller or namespace device @name: The basename of the device to open

This will look for the handle in /dev/ and validate the name and filetype match linux conventions.

Return: A file descriptor for the device on a successful open, or -1 with errno set otherwise.