nvme_root_release_fds

Function nvme_root_release_fds 

pub unsafe extern "C" fn nvme_root_release_fds(r: nvme_root_t)
nvme_root_release_fds - Close all opened file descriptors in the tree @r: &nvme_root_t object

Controller and Namespace objects cache the file descriptors of opened nvme devices. This API can be used to close and clear all cached fds in the tree.