nvme_security_send

Function nvme_security_send 

pub unsafe extern "C" fn nvme_security_send(
    args: *mut nvme_security_send_args,
) -> c_int
nvme_security_send() - Security Send command @args: &struct nvme_security_send argument structure

The Security Send command transfers security protocol data to the controller. The data structure transferred to the controller as part of this command contains security protocol specific commands to be performed by the controller. The data structure transferred may also contain data or parameters associated with the security protocol commands.

The security data is protocol specific and is not defined by the NVMe specification.

Return: The nvme command status if a response was received (see &enum nvme_status_field) or -1 with errno set otherwise.