nvme_set_features_timestamp

Function nvme_set_features_timestamp 

pub unsafe extern "C" fn nvme_set_features_timestamp(
    fd: c_int,
    save: bool,
    timestamp: __u64,
) -> c_int
nvme_set_features_timestamp() - Set timestamp feature @fd: File descriptor of nvme device @save: Save value across power states @timestamp: The current timestamp value to assign to this feature

Return: The nvme command status if a response was received (see &enum nvme_status_field) or -1 with errno set otherwise.