nvme_set_keyring

Function nvme_set_keyring 

pub unsafe extern "C" fn nvme_set_keyring(keyring_id: c_long) -> c_int
nvme_set_keyring() - Link keyring for lookup @keyring_id: Keyring id

Links @keyring_id into the session keyring such that its keys are available for further key lookups.

Return: 0 on success, a negative number on error with errno set.