nvme_submit_admin_passthru

Function nvme_submit_admin_passthru 

pub unsafe extern "C" fn nvme_submit_admin_passthru(
    fd: c_int,
    cmd: *mut nvme_passthru_cmd,
    result: *mut __u32,
) -> c_int
nvme_submit_admin_passthru() - Submit an nvme passthrough admin command @fd: File descriptor of nvme device @cmd: The nvme admin command to send @result: Optional field to return the result from the CQE DW0

Uses NVME_IOCTL_ADMIN_CMD for the ioctl request.

Return: The nvme command status if a response was received (see &enum nvme_status_field) or -1 with errno set otherwise.