pub unsafe extern "C" fn nvme_subsystem_reset(fd: c_int) -> c_intExpand description
nvme_subsystem_reset() - Initiate a subsystem reset @fd: File descriptor of nvme device
This should only be sent to controller handles, not to namespaces.
Return: Zero if a subsystem reset was initiated or -1 with errno set otherwise.