nvmf_add_ctrl

Function nvmf_add_ctrl 

pub unsafe extern "C" fn nvmf_add_ctrl(
    h: nvme_host_t,
    c: nvme_ctrl_t,
    cfg: *const nvme_fabrics_config,
) -> c_int
nvmf_add_ctrl() - Connect a controller and update topology @h: Host to which the controller should be attached @c: Controller to be connected @cfg: Default configuration for the controller

Issues a ‘connect’ command to the NVMe-oF controller and inserts @c into the topology using @h as parent. @c must be initialized and not connected to the topology.

Return: 0 on success; on failure errno is set and -1 is returned.