nvmf_connect_disc_entry

Function nvmf_connect_disc_entry 

pub unsafe extern "C" fn nvmf_connect_disc_entry(
    h: nvme_host_t,
    e: *mut nvmf_disc_log_entry,
    defcfg: *const nvme_fabrics_config,
    discover: *mut bool,
) -> nvme_ctrl_t
nvmf_connect_disc_entry() - Connect controller based on the discovery log page entry @h: Host to which the controller should be connected @e: Discovery log page entry @defcfg: Default configuration to be used for the new controller @discover: Set to ‘true’ if the new controller is a discovery controller

Return: Pointer to the new controller