#[repr(C)]pub struct nvme_capacity_mgmt_args {
pub result: *mut __u32,
pub args_size: c_int,
pub fd: c_int,
pub timeout: __u32,
pub cdw11: __u32,
pub cdw12: __u32,
pub element_id: __u16,
pub op: __u8,
}Expand description
struct nvme_capacity_mgmt_args - Arguments for the NVMe Capacity Management command @result: If successful, the CQE dword0 value @args_size: Size of &struct nvme_capacity_mgmt_args @fd: File descriptor of nvme device @cdw11: Least significant 32 bits of the capacity in bytes of the Endurance Group or NVM Set to be created @cdw12: Most significant 32 bits of the capacity in bytes of the Endurance Group or NVM Set to be created @timeout: Timeout in ms @element_id: Value specific to the value of the Operation field @op: Operation to be performed by the controller
Fields
result: *mut __u32args_size: c_intfd: c_inttimeout: __u32cdw11: __u32cdw12: __u32element_id: __u16op: __u8Trait Implementations
Sourceimpl Clone for nvme_capacity_mgmt_args
impl Clone for nvme_capacity_mgmt_args
Sourcefn clone(&self) -> nvme_capacity_mgmt_args
fn clone(&self) -> nvme_capacity_mgmt_args
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for nvme_capacity_mgmt_args
impl Debug for nvme_capacity_mgmt_args
Sourceimpl Default for nvme_capacity_mgmt_args
impl Default for nvme_capacity_mgmt_args
impl Copy for nvme_capacity_mgmt_args