#[repr(C)]pub struct nvme_fw_commit_args {
pub result: *mut __u32,
pub args_size: c_int,
pub fd: c_int,
pub timeout: __u32,
pub action: nvme_fw_commit_ca,
pub slot: __u8,
pub bpid: bool,
}Expand description
struct nvme_fw_commit_args - Arguments for the NVMe Firmware Commit command @args_size: Size of &struct nvme_fw_commit_args @fd: File descriptor of nvme device @action: Action to use for the firmware image, see &enum nvme_fw_commit_ca @timeout: Timeout in ms @result: The command completion result from CQE dword0 @slot: Firmware slot to commit the downloaded image @bpid: Set to true to select the boot partition id
Fields
result: *mut __u32args_size: c_intfd: c_inttimeout: __u32action: nvme_fw_commit_caslot: __u8bpid: boolTrait Implementations
Sourceimpl Clone for nvme_fw_commit_args
impl Clone for nvme_fw_commit_args
Sourcefn clone(&self) -> nvme_fw_commit_args
fn clone(&self) -> nvme_fw_commit_args
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for nvme_fw_commit_args
impl Debug for nvme_fw_commit_args
Sourceimpl Default for nvme_fw_commit_args
impl Default for nvme_fw_commit_args
impl Copy for nvme_fw_commit_args