#[repr(C)]pub struct nvme_get_features_args {
pub result: *mut __u32,
pub data: *mut c_void,
pub args_size: c_int,
pub fd: c_int,
pub timeout: __u32,
pub nsid: __u32,
pub sel: nvme_get_features_sel,
pub cdw11: __u32,
pub data_len: __u32,
pub fid: __u8,
pub uuidx: __u8,
}Expand description
struct nvme_get_features_args - Arguments for the NVMe Admin Get Feature command @args_size: Size of &struct nvme_get_features_args @fd: File descriptor of nvme device @result: The command completion result from CQE dword0 @timeout: Timeout in ms @nsid: Namespace ID, if applicable @sel: Select which type of attribute to return, see &enum nvme_get_features_sel @cdw11: Feature specific command dword11 field @data_len: Length of feature data, if applicable, in bytes @data: User address of feature data, if applicable @fid: Feature identifier, see &enum nvme_features_id @uuidx: UUID Index for differentiating vendor specific encoding
Fields
result: *mut __u32data: *mut c_voidargs_size: c_intfd: c_inttimeout: __u32nsid: __u32sel: nvme_get_features_selcdw11: __u32data_len: __u32fid: __u8uuidx: __u8Trait Implementations
Sourceimpl Clone for nvme_get_features_args
impl Clone for nvme_get_features_args
Sourcefn clone(&self) -> nvme_get_features_args
fn clone(&self) -> nvme_get_features_args
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for nvme_get_features_args
impl Debug for nvme_get_features_args
Sourceimpl Default for nvme_get_features_args
impl Default for nvme_get_features_args
impl Copy for nvme_get_features_args