#[repr(C)]pub struct nvme_get_log_args {}Expand description
struct nvme_get_log_args - Arguments for the NVMe Admin Get Log command @lpo: Log page offset for partial log transfers @result: The command completion result from CQE dword0 @log: User space destination address to transfer the data @args_size: Length of the structure @fd: File descriptor of nvme device @timeout: Timeout in ms @lid: Log page identifier, see &enum nvme_cmd_get_log_lid for known values @len: Length of provided user buffer to hold the log data in bytes @nsid: Namespace identifier, if applicable @csi: Command set identifier, see &enum nvme_csi for known values @lsi: Log Specific Identifier @lsp: Log specific field @uuidx: UUID selection, if supported @rae: Retain asynchronous events @ot: Offset Type; if set @lpo specifies the index into the list of data structures, otherwise @lpo specifies the byte offset into the log page.
Fields
lpo: __u64result: *mut __u32log: *mut c_voidargs_size: c_intfd: c_inttimeout: __u32lid: nvme_cmd_get_log_lidlen: __u32nsid: __u32csi: nvme_csilsi: __u16lsp: __u8uuidx: __u8rae: boolot: boolTrait Implementations
Sourceimpl Clone for nvme_get_log_args
impl Clone for nvme_get_log_args
Sourcefn clone(&self) -> nvme_get_log_args
fn clone(&self) -> nvme_get_log_args
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more