#[repr(C)]pub struct nvme_identify_args {
pub result: *mut __u32,
pub data: *mut c_void,
pub args_size: c_int,
pub fd: c_int,
pub timeout: __u32,
pub cns: nvme_identify_cns,
pub csi: nvme_csi,
pub nsid: __u32,
pub cntid: __u16,
pub cns_specific_id: __u16,
pub uuidx: __u8,
}Expand description
struct nvme_identify_args - Arguments for the NVMe Identify command @result: The command completion result from CQE dword0 @data: User space destination address to transfer the data @args_size: Size of &struct nvme_identify_args @fd: File descriptor of nvme device @timeout: Timeout in ms (0 for default timeout) @cns: The Controller or Namespace structure, see @enum nvme_identify_cns @csi: Command Set Identifier @nsid: Namespace identifier, if applicable @cntid: The Controller Identifier, if applicable @cns_specific_id: Identifier that is required for a particular CNS value @uuidx: UUID Index if controller supports this id selection method
Fields
result: *mut __u32data: *mut c_voidargs_size: c_intfd: c_inttimeout: __u32cns: nvme_identify_cnscsi: nvme_csinsid: __u32cntid: __u16cns_specific_id: __u16uuidx: __u8Trait Implementations
Sourceimpl Clone for nvme_identify_args
impl Clone for nvme_identify_args
Sourcefn clone(&self) -> nvme_identify_args
fn clone(&self) -> nvme_identify_args
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for nvme_identify_args
impl Debug for nvme_identify_args
Sourceimpl Default for nvme_identify_args
impl Default for nvme_identify_args
impl Copy for nvme_identify_args