#[repr(C)]pub struct nvme_lbaf {
pub ms: __le16,
pub ds: __u8,
pub rp: __u8,
}Expand description
struct nvme_lbaf - LBA Format Data Structure @ms: Metadata Size indicates the number of metadata bytes provided per LBA based on the LBA Data Size indicated. @ds: LBA Data Size indicates the LBA data size supported, reported as a power of two. @rp: Relative Performance, see &enum nvme_lbaf_rp.
Fields
ms: __le16ds: __u8rp: __u8Trait Implementations
impl Copy for nvme_lbaf