#[repr(C)]pub struct nvme_lm_migration_recv_args {}Expand description
struct nvme_lm_migration_recv_args - Arguments for the Migration Receive command @offset: Offset: This field specifies the offset, in bytes, within the data available to be returned and specifies the starting point for that data for what is actually returned to the host. @result: Set on completion to the command’s CQE DWORD 0 controller response @data: Pointer to data @args_size: Length of structure @fd: File descriptor of nvme device @timeout: Timeout in ms @numd: Number of Dwords (NUMD): This field specifies the number of dwords to return. This is a 0’s based value. @mos: Management Operation Specific (MOS): This field is specific to the SEL type @cntlid: Controller ID: This field specifies the identifier of the controller to which the operation is performed. @csuuidi: Controller State UUID Index (CSUUIDI): A non-zero value in this field specifies the index to a specific entry in the Vendor Specific Controller State UUID Supported. list of the Supported Controller State Formats data structure. @sel: Select (SEL): This field specifies the type of management operation to perform @uidx: UUID Index (UIDX): If this field is set to a non-zero value, then the value of this field is the index of a UUID in the UUID List (refer to Figure 320) that is used by the command. @csuidxp: Controller State UUID Index Parameter (CSUIDXP): This field is vendor specific.
Fields
offset: __u64result: *mut __u32data: *mut c_voidargs_size: c_intfd: c_inttimeout: __u32numd: __u32mos: __u16cntlid: __u16csuuidi: __u16sel: __u8uidx: __u8csuidxp: __u8Trait Implementations
Sourceimpl Clone for nvme_lm_migration_recv_args
impl Clone for nvme_lm_migration_recv_args
Sourcefn clone(&self) -> nvme_lm_migration_recv_args
fn clone(&self) -> nvme_lm_migration_recv_args
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more