#[repr(C)]pub struct nvme_lm_migration_send_args {Show 16 fields
pub offset: __u64,
pub result: *mut __u32,
pub data: *mut c_void,
pub args_size: c_int,
pub fd: c_int,
pub timeout: __u32,
pub numd: __u32,
pub mos: __u16,
pub cntlid: __u16,
pub csuuidi: __u16,
pub sel: __u8,
pub uidx: __u8,
pub stype: __u8,
pub seqind: __u8,
pub csvi: __u8,
pub dudmq: bool,
}Expand description
struct nvme_lm_migration_send_args - Arguments for the Migration Send command @offset: Offset: This field specifies the offset, in bytes, within the data available to be returned and specifies the starting point for that data for what is actually returned to the host. @result: Set on completion to the command’s CQE DWORD 0 controller response @data: Pointer to data @args_size: Length of structure @fd: File descriptor of nvme device @timeout: Timeout in ms @numd: Number of Dwords (NUMD): This field specifies the number of dwords being transferred @mos: Management Operation Specific (MOS): This field is specific to the SEL type @cntlid: Controller ID: This field specifies the identifier of the controller to which the operation is performed. @csuuidi: Controller State UUID Index (CSUUIDI): A non-zero value in this field specifies the index to a specific entry in the Vendor Specific Controller State UUID Supported. list of the Supported Controller State Formats data structure. @sel: Select (SEL): This field specifies the type of management operation to perform. @uidx: UUID Index (UIDX): If this field is set to a non-zero value, then the value of this field is the index of a UUID in the UUID List (refer to Figure 320) that is used by the command. @stype: Suspend Type (STYPE): This field specifies the type of suspend. @seqind: Sequence Identifier (SEQIND): This field identified the sequences of this Migration Send command in relation to other Migration Send commands. @csvi: Controller State Version Index (CSVI): A non-zero value in this field specifies the index to a specific entry in the NVMe Controller State Version list of the Supported Controller State Formats data structure. @dudmq: Delete User Data Migration Queue (DUDMQ): If set, the migration queue is deleted is deleted as part of the Suspend operation. If cleared, it is retained.
Fields
offset: __u64result: *mut __u32data: *mut c_voidargs_size: c_intfd: c_inttimeout: __u32numd: __u32mos: __u16cntlid: __u16csuuidi: __u16sel: __u8uidx: __u8stype: __u8seqind: __u8csvi: __u8dudmq: boolTrait Implementations
Sourceimpl Clone for nvme_lm_migration_send_args
impl Clone for nvme_lm_migration_send_args
Sourcefn clone(&self) -> nvme_lm_migration_send_args
fn clone(&self) -> nvme_lm_migration_send_args
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more