#[repr(C)]pub struct nvme_lockdown_args {
pub result: *mut __u32,
pub args_size: c_int,
pub fd: c_int,
pub timeout: __u32,
pub scp: __u8,
pub prhbt: __u8,
pub ifc: __u8,
pub ofi: __u8,
pub uuidx: __u8,
}Expand description
struct nvme_lockdown_args - Arguments for the NVME Lockdown command @args_size: Size of &struct nvme_lockdown_args @fd: File descriptor of nvme device @result: The command completion result from CQE dword0 @timeout: Timeout in ms (0 for default timeout) @scp: Scope of the command @prhbt: Prohibit or allow the command opcode or Set Features command @ifc: Affected interface @ofi: Opcode or Feature Identifier @uuidx: UUID Index if controller supports this id selection method
Fields
result: *mut __u32args_size: c_intfd: c_inttimeout: __u32scp: __u8prhbt: __u8ifc: __u8ofi: __u8uuidx: __u8Trait Implementations
Sourceimpl Clone for nvme_lockdown_args
impl Clone for nvme_lockdown_args
Sourcefn clone(&self) -> nvme_lockdown_args
fn clone(&self) -> nvme_lockdown_args
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for nvme_lockdown_args
impl Debug for nvme_lockdown_args
Sourceimpl Default for nvme_lockdown_args
impl Default for nvme_lockdown_args
impl Copy for nvme_lockdown_args