#[repr(C)]pub struct nvme_lockdown_log {
pub cfila: __u8,
pub rsvd1: [__u8; 2],
pub lngth: __u8,
pub cfil: [__u8; 508],
}Expand description
struct nvme_lockdown_log - Command and Feature Lockdown Log @cfila: Contents of the Command and Feature Identifier List field in the log page. @rsvd1: Reserved @lngth: Length of Command and Feature Identifier List field @cfil: Command and Feature Identifier List
Fields
cfila: __u8rsvd1: [__u8; 2]lngth: __u8cfil: [__u8; 508]Trait Implementations
Sourceimpl Clone for nvme_lockdown_log
impl Clone for nvme_lockdown_log
Sourcefn clone(&self) -> nvme_lockdown_log
fn clone(&self) -> nvme_lockdown_log
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for nvme_lockdown_log
impl Debug for nvme_lockdown_log
Sourceimpl Default for nvme_lockdown_log
impl Default for nvme_lockdown_log
impl Copy for nvme_lockdown_log