nvme_ns_id_desc

Struct nvme_ns_id_desc 

#[repr(C, packed(1))]
pub struct nvme_ns_id_desc { pub nidt: __u8, pub nidl: __u8, pub rsvd: __le16, pub nid: __IncompleteArrayField<__u8>, }
struct nvme_ns_id_desc - Namespace identifier type descriptor @nidt: Namespace Identifier Type, see &enum nvme_ns_id_desc_nidt @nidl: Namespace Identifier Length contains the length in bytes of the &struct nvme_id_ns.nid. @rsvd: Reserved @nid: Namespace Identifier contains a value that is globally unique and assigned to the namespace when the namespace is created. The length is defined in &struct nvme_id_ns.nidl.

Fields

nidt: __u8nidl: __u8rsvd: __le16nid: __IncompleteArrayField<__u8>