nvme_nvmset_attr

Struct nvme_nvmset_attr 

#[repr(C)]
pub struct nvme_nvmset_attr { pub nvmsetid: __le16, pub endgid: __le16, pub rsvd4: [__u8; 4], pub rr4kt: __le32, pub ows: __le32, pub tnvmsetcap: [__u8; 16], pub unvmsetcap: [__u8; 16], pub rsvd48: [__u8; 80], }
struct nvme_nvmset_attr - NVM Set Attributes Entry @nvmsetid: NVM Set Identifier @endgid: Endurance Group Identifier @rsvd4: Reserved @rr4kt: Random 4 KiB Read Typical indicates the typical time to complete a 4 KiB random read in 100 nanosecond units when the NVM Set is in a Predictable Latency Mode Deterministic Window and there is 1 outstanding command per NVM Set. @ows: Optimal Write Size @tnvmsetcap: Total NVM Set Capacity @unvmsetcap: Unallocated NVM Set Capacity @rsvd48: Reserved

Fields

nvmsetid: __le16endgid: __le16rsvd4: [__u8; 4]rr4kt: __le32ows: __le32tnvmsetcap: [__u8; 16]unvmsetcap: [__u8; 16]rsvd48: [__u8; 80]