#[repr(C)]pub struct nvme_resv_acquire_args {
pub crkey: __u64,
pub nrkey: __u64,
pub result: *mut __u32,
pub args_size: c_int,
pub fd: c_int,
pub timeout: __u32,
pub nsid: __u32,
pub rtype: nvme_resv_rtype,
pub racqa: nvme_resv_racqa,
pub iekey: bool,
}Expand description
struct nvme_resv_acquire_args - Arguments for the NVMe Reservation Acquire Command @nrkey: The reservation key to be unregistered from the namespace if the action is preempt @iekey: Set to ignore the existing key @result: The command completion result from CQE dword0 @args_size: Size of &struct nvme_resv_acquire_args @fd: File descriptor of nvme device @timeout: Timeout in ms @nsid: Namespace identifier @rtype: The type of reservation to be create, see &enum nvme_resv_rtype @racqa: The action that is performed by the command, see &enum nvme_resv_racqa @crkey: The current reservation key associated with the host
Fields
crkey: __u64nrkey: __u64result: *mut __u32args_size: c_intfd: c_inttimeout: __u32nsid: __u32rtype: nvme_resv_rtyperacqa: nvme_resv_racqaiekey: boolTrait Implementations
Sourceimpl Clone for nvme_resv_acquire_args
impl Clone for nvme_resv_acquire_args
Sourcefn clone(&self) -> nvme_resv_acquire_args
fn clone(&self) -> nvme_resv_acquire_args
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for nvme_resv_acquire_args
impl Debug for nvme_resv_acquire_args
Sourceimpl Default for nvme_resv_acquire_args
impl Default for nvme_resv_acquire_args
impl Copy for nvme_resv_acquire_args