#[repr(C)]pub struct nvme_resv_register_args {
pub crkey: __u64,
pub nrkey: __u64,
pub result: *mut __u32,
pub args_size: c_int,
pub fd: c_int,
pub timeout: __u32,
pub nsid: __u32,
pub rrega: nvme_resv_rrega,
pub cptpl: nvme_resv_cptpl,
pub iekey: bool,
}Expand description
struct nvme_resv_register_args - Arguments for the NVMe Reservation Register command @crkey: The current reservation key associated with the host @nrkey: The new reservation key to be register if action is register or replace @result: The command completion result from CQE dword0 @args_size: Size of &struct nvme_resv_register_args @fd: File descriptor of nvme device @nsid: Namespace identifier @rrega: The registration action, see &enum nvme_resv_rrega @cptpl: Change persist through power loss, see &enum nvme_resv_cptpl @iekey: Set to ignore the existing key @timeout: Timeout in ms
Fields
crkey: __u64nrkey: __u64result: *mut __u32args_size: c_intfd: c_inttimeout: __u32nsid: __u32rrega: nvme_resv_rregacptpl: nvme_resv_cptpliekey: boolTrait Implementations
Sourceimpl Clone for nvme_resv_register_args
impl Clone for nvme_resv_register_args
Sourcefn clone(&self) -> nvme_resv_register_args
fn clone(&self) -> nvme_resv_register_args
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for nvme_resv_register_args
impl Debug for nvme_resv_register_args
Sourceimpl Default for nvme_resv_register_args
impl Default for nvme_resv_register_args
impl Copy for nvme_resv_register_args