nvme_st_result

Struct nvme_st_result 

#[repr(C, packed(1))]
pub struct nvme_st_result { pub dsts: __u8, pub seg: __u8, pub vdi: __u8, pub rsvd: __u8, pub poh: __le64, pub nsid: __le32, pub flba: __le64, pub sct: __u8, pub sc: __u8, pub vs: [__u8; 2], }
struct nvme_st_result - Self-test Result @dsts: Device Self-test Status: Indicates the device self-test code and the status of the operation (see &enum nvme_status_result and &enum nvme_st_code). @seg: Segment Number: Iindicates the segment number where the first self-test failure occurred. If Device Self-test Status (@dsts) is not set to #NVME_ST_RESULT_KNOWN_SEG_FAIL, then this field should be ignored. @vdi: Valid Diagnostic Information: Indicates the diagnostic failure information that is reported. See &enum nvme_st_valid_diag_info. @rsvd: Reserved @poh: Power On Hours (POH): Indicates the number of power-on hours at the time the device self-test operation was completed or aborted. This does not include time that the controller was powered and in a low power state condition. @nsid: Namespace Identifier (NSID): Indicates the namespace that the Failing LBA occurred on. Valid only when the NSID Valid bit (#NVME_ST_VALID_DIAG_INFO_NSID) is set in the Valid Diagnostic Information (@vdi) field. @flba: Failing LBA: indicates the LBA of the logical block that caused the test to fail. If the device encountered more than one failed logical block during the test, then this field only indicates one of those failed logical blocks. Valid only when the NSID Valid bit (#NVME_ST_VALID_DIAG_INFO_FLBA) is set in the Valid Diagnostic Information (@vdi) field. @sct: Status Code Type: This field may contain additional information related to errors or conditions. Bits 2:0 may contain additional information relating to errors or conditions that occurred during the device self-test operation represented in the same format used in the Status Code Type field of the completion queue entry (refer to &enum nvme_status_field). Valid only when the NSID Valid bit (#NVME_ST_VALID_DIAG_INFO_SCT) is set in the Valid Diagnostic Information (@vdi) field. @sc: Status Code: This field may contain additional information relating to errors or conditions that occurred during the device self-test operation represented in the same format used in the Status Code field of the completion queue entry. Valid only when the SCT Valid bit (#NVME_ST_VALID_DIAG_INFO_SC) is set in the Valid Diagnostic Information (@vdi) field. @vs: Vendor Specific.

Fields

dsts: __u8seg: __u8vdi: __u8rsvd: __u8poh: __le64nsid: __le32flba: __le64sct: __u8sc: __u8vs: [__u8; 2]