nvmf_discovery_log

Struct nvmf_discovery_log 

#[repr(C)]
pub struct nvmf_discovery_log { pub genctr: __le64, pub numrec: __le64, pub recfmt: __le16, pub rsvd14: [__u8; 1006], pub entries: __IncompleteArrayField<nvmf_disc_log_entry>, }
struct nvmf_discovery_log - Discovery Log Page (Log Identifier 70h) @genctr: Generation Counter (GENCTR): Indicates the version of the discovery information, starting at a value of 0h. For each change in the Discovery Log Page, this counter is incremented by one. If the value of this field is FFFFFFFF_FFFFFFFFh, then the field shall be cleared to 0h when incremented (i.e., rolls over to 0h). @numrec: Number of Records (NUMREC): Indicates the number of records contained in the log. @recfmt: Record Format (RECFMT): Specifies the format of the Discovery Log Page. If a new format is defined, this value is incremented by one. The format of the record specified in this definition shall be 0h. @rsvd14: Reserved @entries: Discovery Log Page Entries - see &struct nvmf_disc_log_entry.

Fields

genctr: __le64numrec: __le64recfmt: __le16rsvd14: [__u8; 1006]entries: __IncompleteArrayField<nvmf_disc_log_entry>