pub type nvme_bpinfo = c_uint;Expand description
enum nvme_bpinfo - This field indicates the boot partition information @NVME_BPINFO_BPSZ_SHIFT: Shift amount to get the boot partition size @NVME_BPINFO_BRS_SHIFT: Shift amount to get the boot read status @NVME_BPINFO_ABPID_SHIFT: Shift amount to get the active boot partition ID @NVME_BPINFO_BPSZ_MASK: Mask to get the boot partition size @NVME_BPINFO_BRS_MASK: Mask to get the boot read status @NVME_BPINFO_ABPID_MASK: Mask to get the active boot partition ID @NVME_BPINFO_BRS_NONE: No boot partition read operation requested @NVME_BPINFO_BRS_READ_IN_PROGRESS: Boot partition read in progress @NVME_BPINFO_BRS_READ_SUCCESS: Boot partition read completed successfully @NVME_BPINFO_BRS_READ_ERROR: Error completing boot partition read