nvme_bprsel

Type Alias nvme_bprsel 

pub type nvme_bprsel = c_uint;
enum nvme_bprsel - This field indicates the boot partition read select @NVME_BPRSEL_BPRSZ_SHIFT: Shift amount to get the boot partition read size @NVME_BPRSEL_BPROF_SHIFT: Shift amount to get the boot partition read offset @NVME_BPRSEL_BPID_SHIFT: Shift amount to get the boot partition identifier @NVME_BPRSEL_BPRSZ_MASK: Mask to get the boot partition read size @NVME_BPRSEL_BPROF_MASK: Mask to get the boot partition read offset @NVME_BPRSEL_BPID_MASK: Mask to get the boot partition identifier