nvme_cc

Type Alias nvme_cc 

pub type nvme_cc = c_uint;
enum nvme_cc - This field indicates the controller configuration @NVME_CC_EN_SHIFT: Shift amount to get the enable @NVME_CC_CSS_SHIFT: Shift amount to get the I/O command set selected @NVME_CC_MPS_SHIFT: Shift amount to get the memory page size @NVME_CC_AMS_SHIFT: Shift amount to get the arbitration mechanism selected @NVME_CC_SHN_SHIFT: Shift amount to get the shutdown notification @NVME_CC_IOSQES_SHIFT: Shift amount to get the I/O submission queue entry size @NVME_CC_IOCQES_SHIFT: Shift amount to get the I/O completion queue entry size @NVME_CC_CRIME_SHIFT: Shift amount to get the controller ready independent of media enable @NVME_CC_EN_MASK: Mask to get the enable @NVME_CC_CSS_MASK: Mask to get the I/O command set selected @NVME_CC_MPS_MASK: Mask to get the memory page size @NVME_CC_AMS_MASK: Mask to get the arbitration mechanism selected @NVME_CC_SHN_MASK: Mask to get the shutdown notification @NVME_CC_CRIME_MASK: Mask to get the I/O submission queue entry size @NVME_CC_IOSQES_MASK: Mask to get the I/O completion queue entry size @NVME_CC_IOCQES_MASK: Mask to get the controller ready independent of media enable @NVME_CC_CSS_NVM: NVM command set @NVME_CC_CSS_CSI: All supported I/O command sets @NVME_CC_CSS_ADMIN: Admin command set only @NVME_CC_AMS_RR: Round robin @NVME_CC_AMS_WRRU: Weighted round robin with urgent priority class @NVME_CC_AMS_VS: Vendor specific @NVME_CC_SHN_NONE: No notification; no effect @NVME_CC_SHN_NORMAL: Normal shutdown notification @NVME_CC_SHN_ABRUPT: Abrupt shutdown notification @NVME_CC_CRWME: Controller ready with media enable @NVME_CC_CRIME: Controller ready independent of media enable