nvme_cmbebs

Type Alias nvme_cmbebs 

pub type nvme_cmbebs = c_uint;
enum nvme_cmbebs - This field indicates the controller memory buffer elasticity buffer size @NVME_CMBEBS_CMBSZU_SHIFT: Shift amount to get the CMB elasticity buffer size units @NVME_CMBEBS_RBB_SHIFT: Shift amount to get the read bypass behavior @NVME_CMBEBS_CMBWBZ_SHIFT: Shift amount to get the CMB elasiticity buffer size base @NVME_CMBEBS_CMBSZU_MASK: Mask to get the CMB elasticity buffer size units @NVME_CMBEBS_RBB_MASK: Mask to get the read bypass behavior @NVME_CMBEBS_CMBWBZ_MASK: Mask to get the CMB elasiticity buffer size base @NVME_CMBEBS_CMBSZU_B: Bytes granularity @NVME_CMBEBS_CMBSZU_1K: 1 KiB granularity @NVME_CMBEBS_CMBSZU_1M: 1 MiB granularity @NVME_CMBEBS_CMBSZU_1G: 1 GiB granularity