nvme_cmbloc

Type Alias nvme_cmbloc 

pub type nvme_cmbloc = c_uint;
enum nvme_cmbloc - This field indicates the controller memory buffer location @NVME_CMBLOC_BIR_SHIFT: Shift amount to get the base indicator register @NVME_CMBLOC_CQMMS_SHIFT: Shift amount to get the CMB queue mixed memory support @NVME_CMBLOC_CQPDS_SHIFT: Shift amount to get the CMB queue physically discontiguous support @NVME_CMBLOC_CDPLMS_SHIFT: Shift amount to get the CMB data pointer mixed locations support @NVME_CMBLOC_CDPCILS_SHIFT: Shift amount to get the CMB data pointer and command independent locations support @NVME_CMBLOC_CDMMMS_SHIFT: Shift amount to get the CMB data metadata mixed memory support @NVME_CMBLOC_CQDA_SHIFT: Shift amount to get the CMB queue dword alignment @NVME_CMBLOC_OFST_SHIFT: Shift amount to get the offset @NVME_CMBLOC_BIR_MASK: Mask to get the base indicator register @NVME_CMBLOC_CQMMS_MASK: Mask to get the CMB queue mixed memory support @NVME_CMBLOC_CQPDS_MASK: Mask to get the CMB queue physically discontiguous support @NVME_CMBLOC_CDPLMS_MASK: Mask to get the CMB data pointer mixed locations support @NVME_CMBLOC_CDPCILS_MASK: Mask to get the CMB data pointer and command independent locations support @NVME_CMBLOC_CDMMMS_MASK: Mask to get the CMB data metadata mixed memory support @NVME_CMBLOC_CQDA_MASK: Mask to get the CMB queue dword alignment @NVME_CMBLOC_OFST_MASK: Mask to get the offset