nvme_cmic

Type Alias nvme_cmic 

pub type nvme_cmic = c_uint;
enum nvme_cmic - This field indicates the controller multi-path I/O and NS sharing capabilities @NVME_CMIC_MULTI_PORT_SHIFT: Shift amount to get the NVM subsystem port @NVME_CMIC_MULTI_CTRL_SHIFT: Shift amount to get the controllers @NVME_CMIC_MULTI_SRIOV_SHIFT: Shift amount to get the SR-IOV virtual function @NVME_CMIC_MULTI_ANA_SHIFT: Shift amount to get the asymmetric namespace access reporting @NVME_CMIC_MULTI_RSVD_SHIFT: Shift amount to get the reserved @NVME_CMIC_MULTI_PORT_MASK: Mask to get the NVM subsystem port @NVME_CMIC_MULTI_CTRL_MASK: Mask to get the controllers @NVME_CMIC_MULTI_SRIOV_MASK: Mask to get the SR-IOV virtual function @NVME_CMIC_MULTI_ANA_MASK: Mask to get the asymmetric namespace access reporting @NVME_CMIC_MULTI_RSVD_MASK: Mask to get the reserved