nvme_constants

Type Alias nvme_constants 

pub type nvme_constants = c_uint;
enum nvme_constants - A place to stash various constant nvme values @NVME_NSID_ALL: A broadcast value that is used to specify all namespaces @NVME_NSID_NONE: The invalid namespace id, for when the nsid parameter is not used in a command @NVME_UUID_NONE: Use to omit a uuid command parameter @NVME_CNTLID_NONE: Use to omit a cntlid command parameter @NVME_CNSSPECID_NONE: Use to omit a cns_specific_id command parameter @NVME_LOG_LSP_NONE: Use to omit a log lsp command parameter @NVME_LOG_LSI_NONE: Use to omit a log lsi command parameter @NVME_LOG_LPO_NONE: Use to omit a log lpo command parameter @NVME_IDENTIFY_DATA_SIZE: The transfer size for nvme identify commands @NVME_LOG_SUPPORTED_LOG_PAGES_MAX: The largest possible index in the supported log pages log. @NVME_ID_NVMSET_LIST_MAX: The largest possible nvmset index in identify nvmeset @NVME_ID_UUID_LIST_MAX: The largest possible uuid index in identify uuid list @NVME_ID_CTRL_LIST_MAX: The largest possible controller index in identify controller list @NVME_ID_NS_LIST_MAX: The largest possible namespace index in identify namespace list @NVME_ID_SECONDARY_CTRL_MAX: The largest possible secondary controller index in identify secondary controller @NVME_ID_DOMAIN_LIST_MAX: The largest possible domain index in the in domain list @NVME_ID_ENDURANCE_GROUP_LIST_MAX: The largest possible endurance group index in the endurance group list @NVME_ID_ND_DESCRIPTOR_MAX: The largest possible namespace granularity index in the namespace granularity descriptor list @NVME_FEAT_LBA_RANGE_MAX: The largest possible LBA range index in feature lba range type @NVME_LOG_ST_MAX_RESULTS: The largest possible self test result index in the device self test log @NVME_LOG_FID_SUPPORTED_EFFECTS_MAX: The largest possible FID index in the feature identifiers effects log. @NVME_LOG_MI_CMD_SUPPORTED_EFFECTS_MAX: The largest possible MI Command index in the MI Command effects log. @NVME_LOG_MI_CMD_SUPPORTED_EFFECTS_RESERVED: The reserved space in the MI Command effects log. @NVME_LOG_TELEM_BLOCK_SIZE: Specification defined size of Telemetry Data Blocks @NVME_DSM_MAX_RANGES: The largest possible range index in a data-set management command @NVME_NQN_LENGTH: Max length for NVMe Qualified Name @NVMF_TRADDR_SIZE: Max Transport Address size @NVMF_TSAS_SIZE: Max Transport Specific Address Subtype size @NVME_ZNS_CHANGED_ZONES_MAX: Max number of zones in the changed zones log page @NVME_STREAM_ID_MAX: Max number of stream IDs