nvme_flbas

Type Alias nvme_flbas 

pub type nvme_flbas = c_uint;
enum nvme_flbas - This field indicates the formatted LBA size @NVME_FLBAS_LOWER_SHIFT: Shift amount to get the format index least significant 4 bits @NVME_FLBAS_META_EXT_SHIFT: Shift amount to get the metadata transferred @NVME_FLBAS_HIGHER_SHIFT: Shift amount to get the format index most significant 2 bits @NVME_FLBAS_LOWER_MASK: Mask to get the format index least significant 4 bits @NVME_FLBAS_META_EXT_MASK: Mask to get the metadata transferred @NVME_FLBAS_HIGHER_MASK: Mask to get the format index most significant 2 bits