pub type nvme_fw_commit_ca = c_uint;Expand description
enum nvme_fw_commit_ca - Firmware Commit - Commit Action @NVME_FW_COMMIT_CA_REPLACE: Downloaded image replaces the existing image, if any, in the specified Firmware Slot. The newly placed image is not activated. @NVME_FW_COMMIT_CA_REPLACE_AND_ACTIVATE: Downloaded image replaces the existing image, if any, in the specified Firmware Slot. The newly placed image is activated at the next Controller Level Reset. @NVME_FW_COMMIT_CA_SET_ACTIVE: The existing image in the specified Firmware Slot is activated at the next Controller Level Reset. @NVME_FW_COMMIT_CA_REPLACE_AND_ACTIVATE_IMMEDIATE: Downloaded image replaces the existing image, if any, in the specified Firmware Slot and is then activated immediately. If there is not a newly downloaded image, then the existing image in the specified firmware slot is activated immediately. @NVME_FW_COMMIT_CA_REPLACE_BOOT_PARTITION: Downloaded image replaces the Boot Partition specified by the Boot Partition ID field. @NVME_FW_COMMIT_CA_ACTIVATE_BOOT_PARTITION: Mark the Boot Partition specified in the BPID field as active and update BPINFO.ABPID.