nvme_id_ctrl_anacap

Type Alias nvme_id_ctrl_anacap 

pub type nvme_id_ctrl_anacap = c_uint;
enum nvme_id_ctrl_anacap - This field indicates the capabilities associated with Asymmetric Namespace Access Reporting. @NVME_CTRL_ANACAP_OPT: If set, then the controller is able to report ANA Optimized state. @NVME_CTRL_ANACAP_NON_OPT: If set, then the controller is able to report ANA Non-Optimized state. @NVME_CTRL_ANACAP_INACCESSIBLE: If set, then the controller is able to report ANA Inaccessible state. @NVME_CTRL_ANACAP_PERSISTENT_LOSS: If set, then the controller is able to report ANA Persistent Loss state. @NVME_CTRL_ANACAP_CHANGE: If set, then the controller is able to report ANA Change state. @NVME_CTRL_ANACAP_GRPID_NO_CHG: If set, then the ANAGRPID field in the Identify Namespace data structure (&struct nvme_id_ns.anagrpid), does not change while the namespace is attached to any controller. @NVME_CTRL_ANACAP_GRPID_MGMT: If set, then the controller supports a non-zero value in the ANAGRPID field of the Namespace Management command.