nvme_id_ctrl_apsta

Type Alias nvme_id_ctrl_apsta 

pub type nvme_id_ctrl_apsta = c_uint;
enum nvme_id_ctrl_apsta - Flags indicating the attributes of the autonomous power state transition feature. @NVME_CTRL_APSTA_APST: If set, then the controller supports autonomous power state transitions.