nvme_id_ctrl_avscc

Type Alias nvme_id_ctrl_avscc 

pub type nvme_id_ctrl_avscc = c_uint;
enum nvme_id_ctrl_avscc - Flags indicating the configuration settings for Admin Vendor Specific command handling. @NVME_CTRL_AVSCC_AVS: If set, all Admin Vendor Specific Commands use the optional vendor specific command format with NDT and NDM fields.