nvme_id_ctrl_bpcap

Type Alias nvme_id_ctrl_bpcap 

pub type nvme_id_ctrl_bpcap = c_uint;
enum nvme_id_ctrl_bpcap - Boot Partition Capabilities @NVME_CTRL_BACAP_RPMBBPWPS_SHIFT: Shift amount to get the RPMB Boot Partition Write Protection Support from the &struct nvme_id_ctrl.bpcap field. @NVME_CTRL_BACAP_SFBPWPS_SHIFT: Shift amount to get the Set Features Boot Partition Write Protection Support from the &struct nvme_id_ctrl.bpcap field. @NVME_CTRL_BACAP_RPMBBPWPS_MASK: Mask to get the RPMB Boot Partition Write Protection Support from the &struct nvme_id_ctrl.bpcap field. @NVME_CTRL_BACAP_SFBPWPS_MASK: Mask to get the Set Features Boot Partition Write Protection Support from the &struct nvme_id_ctrl.bpcap field. @NVME_CTRL_BACAP_RPMBBPWPS_NOT_SPECIFIED: Support for RPMB Boot Partition Write Protection is not specified. @NVME_CTRL_BACAP_RPMBBPWPS_NOT_SUPPORTED: RPMB Boot Partition Write Protection is not supported by this controller. @NVME_CTRL_BACAP_RPMBBPWPS_SUPPORTED: RPMB Boot Partition Write Protection is supported by this controller.