nvme_id_ctrl_cqes

Type Alias nvme_id_ctrl_cqes 

pub type nvme_id_ctrl_cqes = c_uint;
enum nvme_id_ctrl_cqes - Defines the required and maximum Completion Queue entry size when using the NVM Command Set. @NVME_CTRL_CQES_MIN: Mask to get the value of the required Completion Queue Entry size when using the NVM Command Set. @NVME_CTRL_CQES_MAX: Mask to get the value of the maximum Completion Queue entry size when using the NVM Command Set.