nvme_id_ctrl_crcap

Type Alias nvme_id_ctrl_crcap 

pub type nvme_id_ctrl_crcap = c_uint;
enum nvme_id_ctrl_crcap - Power Loss Signaling Information @NVME_CTRL_CRCAP_RRSUP_SHIFT: Shift amount to get the Reachability Reporting Supported from the &struct nvme_id_ctrl.crcap field. @NVME_CTRL_CRCAP_RGIDC_SHIFT: Shift amount to get the Reachability Group ID Changeable from the &struct nvme_id_ctrl.crcap field. @NVME_CTRL_CRCAP_RRSUP_MASK: Mask to get the Reachability Reporting Supported from the &struct nvme_id_ctrl.crcap field. @NVME_CTRL_CRCAP_RGIDC_MASK: Mask to get the Reachability Group ID Changeable from the &struct nvme_id_ctrl.crcap field.