nvme_id_ctrl_dsto

Type Alias nvme_id_ctrl_dsto 

pub type nvme_id_ctrl_dsto = c_uint;
enum nvme_id_ctrl_dsto - Flags indicating the optional Device Self-test command or operation behaviors supported by the controller or NVM subsystem. @NVME_CTRL_DSTO_SDSO_SHIFT: Shift amount to get the value of Single Device Self-test Operation from Device Self-test Options field. @NVME_CTRL_DSTO_HIRS_SHIFT: Shift amount to get the value of Host-Initiated Refresh Support from Device Self-test Options field. @NVME_CTRL_DSTO_SDSO_MASK: Mask to get the value of Single Device Self-test Operation @NVME_CTRL_DSTO_HIRS_MASK: Mask to get the value of Host-Initiated Refresh Support @NVME_CTRL_DSTO_ONE_DST: If set, then the NVM subsystem supports only one device self-test operation in progress at a time. If cleared, then the NVM subsystem supports one device self-test operation per controller at a time. @NVME_CTRL_DSTO_HIRS: If set, then the controller supports the Host-Initiated Refresh capability.