pub type nvme_id_ctrl_fna = c_uint;Expand description
enum nvme_id_ctrl_fna - This field indicates attributes for the Format NVM command. @NVME_CTRL_FNA_FMT_ALL_NS_SHIFT: Shift amount to get the format applied to all namespaces @NVME_CTRL_FNA_SEC_ALL_NS_SHIFT: Shift amount to get the secure erase applied to all namespaces @NVME_CTRL_FNA_CES_SHIFT: Shift amount to get the cryptographic erase supported @NVME_CTRL_FNA_NSID_ALL_F_SHIFT: Shift amount to get the format supported an NSID FFFFFFFFh @NVME_CTRL_FNA_FMT_ALL_NS_MASK: Mask to get the format applied to all namespaces @NVME_CTRL_FNA_SEC_ALL_NS_MASK: Mask to get the secure erase applied to all namespaces @NVME_CTRL_FNA_CES_MASK: Mask to get the cryptographic erase supported @NVME_CTRL_FNA_NSID_ALL_F_MASK: Mask to get the format supported an NSID FFFFFFFFh @NVME_CTRL_FNA_FMT_ALL_NAMESPACES: If set, then all namespaces in an NVM subsystem shall be configured with the same attributes and a format (excluding secure erase) of any namespace results in a format of all namespaces in an NVM subsystem. If cleared, then the controller supports format on a per namespace basis. @NVME_CTRL_FNA_SEC_ALL_NAMESPACES: If set, then any secure erase performed as part of a format operation results in a secure erase of all namespaces in the NVM subsystem. If cleared, then any secure erase performed as part of a format results in a secure erase of the particular namespace specified. @NVME_CTRL_FNA_CRYPTO_ERASE: If set, then cryptographic erase is supported. If cleared, then cryptographic erase is not supported. @NVME_CTRL_FNA_NSID_FFFFFFFF: If set, then format does not support nsid value set to FFFFFFFFh. If cleared, format supports nsid value set to FFFFFFFFh.