pub type nvme_id_ctrl_frmw = c_uint;Expand description
enum nvme_id_ctrl_frmw - Flags and values indicates capabilities regarding firmware updates from &struct nvme_id_ctrl.frmw. @NVME_CTRL_FRMW_1ST_RO: If set, the first firmware slot is readonly @NVME_CTRL_FRMW_NR_SLOTS: Mask to get the value of the number of firmware slots that the controller supports. @NVME_CTRL_FRMW_FW_ACT_NO_RESET: If set, the controller supports firmware activation without a reset. @NVME_CTRL_FRMW_MP_UP_DETECTION: If set, the controller is able to detect overlapping firmware/boot partition image update.