nvme_id_ctrl_fuses

Type Alias nvme_id_ctrl_fuses 

pub type nvme_id_ctrl_fuses = c_uint;
enum nvme_id_ctrl_fuses - This field indicates the fused operations that the controller supports. @NVME_CTRL_FUSES_COMPARE_AND_WRITE: If set, then the controller supports the Compare and Write fused operation.