pub type nvme_id_ctrl_mec = c_uint;Expand description
enum nvme_id_ctrl_mec - Flags indicating the capabilities of the Management Endpoint in the Controller, &struct nvme_id_ctrl.mec. @NVME_CTRL_MEC_SMBUSME: If set, then the NVM Subsystem contains a Management Endpoint on an SMBus/I2C port. @NVME_CTRL_MEC_PCIEME: If set, then the NVM Subsystem contains a Management Endpoint on a PCIe port.