pub type nvme_id_ctrl_oacs = c_uint;Expand description
enum nvme_id_ctrl_oacs - Flags indicating the optional Admin commands and features supported by the controller, see &struct nvme_id_ctrl.oacs. @NVME_CTRL_OACS_SSRS_SHIFT: Shift amount to get the Security Send Receive supported @NVME_CTRL_OACS_FNVMS_SHIFT:Shift amount to get the Format NVM supported @NVME_CTRL_OACS_FWDS_SHIFT: Shift amount to get the Firmware Download supported @NVME_CTRL_OACS_NMS_SHIFT: Shift amount to get the Namespace Management supported @NVME_CTRL_OACS_DSTS_SHIFT: Shift amount to get the Device Self-test supported @NVME_CTRL_OACS_DIRS_SHIFT: Shift amount to get the Directives supported @NVME_CTRL_OACS_NSRS_SHIFT: Shift amount to get the NVMe-MI Send Receive supported @NVME_CTRL_OACS_VMS_SHIFT: Shift amount to get the Virtualization Management supported @NVME_CTRL_OACS_DBCS_SHIFT: Shift amount to get the Doorbell Buffer Config supported @NVME_CTRL_OACS_GLSS_SHIFT: Shift amount to get the Get LBA Status supported @NVME_CTRL_OACS_CFLS_SHIFT: Shift amount to get the Command and Feature Lockdown supported @NVME_CTRL_OACS_HMLMS_SHIFT:Shift amount to get the Host Managed Live Migration support @NVME_CTRL_OACS_SSRS_MASK: Mask to get the Security Send Receive supported @NVME_CTRL_OACS_FNVMS_MASK: Mask to get the Format NVM supported @NVME_CTRL_OACS_FWDS_MASK: Mask to get the Firmware Download supported @NVME_CTRL_OACS_NMS_MASK: Mask to get the Namespace Management supported @NVME_CTRL_OACS_DSTS_MASK: Mask to get the Device Self-test supported @NVME_CTRL_OACS_DIRS_MASK: Mask to get the Directives supported @NVME_CTRL_OACS_NSRS_MASK: Mask to get the NVMe-MI Send Receive supported @NVME_CTRL_OACS_VMS_MASK: Mask to get the Virtualization Management supported @NVME_CTRL_OACS_DBCS_MASK: Mask to get the Doorbell Buffer Config supported @NVME_CTRL_OACS_GLSS_MASK: Mask to get the Get LBA Status supported @NVME_CTRL_OACS_CFLS_MASK: Mask to get the Command and Feature Lockdown supported @NVME_CTRL_OACS_HMLMS_MASK: Mask to get the Host Managed Live Migration support @NVME_CTRL_OACS_SECURITY: If set, then the controller supports the Security Send and Security Receive commands. @NVME_CTRL_OACS_FORMAT: If set then the controller supports the Format NVM command. @NVME_CTRL_OACS_FW: If set, then the controller supports the Firmware Commit and Firmware Image Download commands. @NVME_CTRL_OACS_NS_MGMT: If set, then the controller supports the Namespace Management capability @NVME_CTRL_OACS_SELF_TEST: If set, then the controller supports the Device Self-test command. @NVME_CTRL_OACS_DIRECTIVES: If set, then the controller supports Directives and the Directive Send and Directive Receive commands. @NVME_CTRL_OACS_NVME_MI: If set, then the controller supports the NVMe-MI Send and NVMe-MI Receive commands. @NVME_CTRL_OACS_VIRT_MGMT: If set, then the controller supports the Virtualization Management command. @NVME_CTRL_OACS_DBBUF_CFG: If set, then the controller supports the Doorbell Buffer Config command. @NVME_CTRL_OACS_LBA_STATUS: If set, then the controller supports the Get LBA Status capability. @NVME_CTRL_OACS_CMD_FEAT_LD:If set, then the controller supports the command and feature lockdown capability. @NVME_CTRL_OACS_HMLM: If set, then the controller supports the command and Host Managed Live Migration capability.