nvme_id_ctrl_oaes

Type Alias nvme_id_ctrl_oaes 

pub type nvme_id_ctrl_oaes = c_int;
enum nvme_id_ctrl_oaes - Optional Asynchronous Events Supported @NVME_CTRL_OAES_NA_SHIFT: Shift amount to get the Namespace Attribute Notices event supported @NVME_CTRL_OAES_FA_SHIFT: Shift amount to get the Firmware Activation Notices event supported @NVME_CTRL_OAES_ANA_SHIFT: Shift amount to get the ANA Change Notices supported @NVME_CTRL_OAES_PLEA_SHIFT: Shift amount to get the Predictable Latency Event Aggregate Log Change Notices event supported @NVME_CTRL_OAES_LBAS_SHIFT: Shift amount to get the LBA Status Information Notices event supported @NVME_CTRL_OAES_EGE_SHIFT: Shift amount to get the Endurance Group Events Aggregate Log Change Notices event supported @NVME_CTRL_OAES_NS_SHIFT: Shift amount to get the Normal NVM Subsystem Shutdown event supported @NVME_CTRL_OAES_TTH_SHIFT: Shift amount to get the Temperature Threshold Hysteresis Recovery event supported @NVME_CTRL_OAES_RGCNS_SHIFT: Shift amount to get the Reachability Groups Change Notices supported @NVME_CTRL_OAES_ANSAN_SHIFT: Shift amount to get the Allocated Namespace Attribute Notices supported @NVME_CTRL_OAES_ZD_SHIFT: Shift amount to get the Zone Descriptor Change Notifications supported @NVME_CTRL_OAES_DL_SHIFT: Shift amount to get the Discover Log Page Change Notifications supported @NVME_CTRL_OAES_NA_MASK: Mask to get the Namespace Attribute Notices event supported @NVME_CTRL_OAES_FA_MASK: Mask to get the Firmware Activation Notices event supported @NVME_CTRL_OAES_ANA_MASK: Mask to get the ANA Change Notices supported @NVME_CTRL_OAES_PLEA_MASK: Mask to get the Predictable Latency Event Aggregate Log Change Notices event supported @NVME_CTRL_OAES_LBAS_MASK: Mask to get the LBA Status Information Notices event supported @NVME_CTRL_OAES_EGE_MASK: Mask to get the Endurance Group Events Aggregate Log Change Notices event supported @NVME_CTRL_OAES_NS_MASK: Mask to get the Normal NVM Subsystem Shutdown event supported @NVME_CTRL_OAES_TTH_MASK: Mask to get the Temperature Threshold Hysteresis Recovery event supported @NVME_CTRL_OAES_RGCNS_MASK: Mask to get the Reachability Groups Change Notices supported @NVME_CTRL_OAES_ANSAN_MASK: Mask to get the Allocated Namespace Attribute Notices supported @NVME_CTRL_OAES_ZD_MASK: Mask to get the Zone Descriptor Change Notifications supported @NVME_CTRL_OAES_DL_MASK: Mask to get the Discover Log Page Change Notifications supported @NVME_CTRL_OAES_NA: Namespace Attribute Notices event supported @NVME_CTRL_OAES_FA: Firmware Activation Notices event supported @NVME_CTRL_OAES_ANA: ANA Change Notices supported @NVME_CTRL_OAES_PLEA: Predictable Latency Event Aggregate Log Change Notices event supported @NVME_CTRL_OAES_LBAS: LBA Status Information Notices event supported @NVME_CTRL_OAES_EGE: Endurance Group Events Aggregate Log Change Notices event supported @NVME_CTRL_OAES_NS: Normal NVM Subsystem Shutdown event supported @NVME_CTRL_OAES_TTH: Temperature Threshold Hysteresis Recovery event supported @NVME_CTRL_OAES_RGCNS: Reachability Groups Change Notices supported @NVME_CTRL_OAES_ANSAN: Allocated Namespace Attribute Notices supported @NVME_CTRL_OAES_ZD: Zone Descriptor Change Notifications supported @NVME_CTRL_OAES_DL: Discover Log Page Change Notifications supported