pub type nvme_id_ctrl_sanicap = c_int;Expand description
enum nvme_id_ctrl_sanicap - Indicates attributes for sanitize operations. @NVME_CTRL_SANICAP_CES: Crypto Erase Support. If set, then the controller supports the Crypto Erase sanitize operation. @NVME_CTRL_SANICAP_BES: Block Erase Support. If set, then the controller supports the Block Erase sanitize operation. @NVME_CTRL_SANICAP_OWS: Overwrite Support. If set, then the controller supports the Overwrite sanitize operation. @NVME_CTRL_SANICAP_NDI: No-Deallocate Inhibited. If set and the No- Deallocate Response Mode bit is set, then the controller deallocates after the sanitize operation even if the No-Deallocate After Sanitize bit is set in a Sanitize command. @NVME_CTRL_SANICAP_NODMMAS: No-Deallocate Modifies Media After Sanitize, mask to extract value.