nvme_id_ctrl_trattr

Type Alias nvme_id_ctrl_trattr 

pub type nvme_id_ctrl_trattr = c_uint;
enum nvme_id_ctrl_trattr - Tracking Attributes @NVME_CTRL_TRATTR_THMCS_SHIFT: Shift amount to get the Track Host Memory Changes Support from the &struct nvme_id_ctrl.trattr field. @NVME_CTRL_TRATTR_TUDCS_SHIFT: Shift amount to get the Track User Data Changes Support from the &struct nvme_id_ctrl.trattr field. @NVME_CTRL_TRATTR_MRTLL_SHIFT: Shift amount to get the Memory Range Tracking Length Limit from the &struct nvme_id_ctrl.trattr field. @NVME_CTRL_TRATTR_THMCS_MASK: Mask to get the Track Host Memory Changes Support from the &struct nvme_id_ctrl.trattr field. @NVME_CTRL_TRATTR_TUDCS_MASK: Mask to get the Track User Data Changes Support from the &struct nvme_id_ctrl.trattr field. @NVME_CTRL_TRATTR_MRTLL_MASK: Mask to get the Memory Range Tracking Length Limit from the &struct nvme_id_ctrl.trattr field.