nvme_id_ctrl_vwc

Type Alias nvme_id_ctrl_vwc 

pub type nvme_id_ctrl_vwc = c_uint;
enum nvme_id_ctrl_vwc - Volatile write cache @NVME_CTRL_VWC_PRESENT: If set, indicates a volatile write cache is present. If a volatile write cache is present, then the host controls whether the volatile write cache is enabled with a Set Features command specifying the value %NVME_FEAT_FID_VOLATILE_WC. @NVME_CTRL_VWC_FLUSH: Mask to get the value of the flush command behavior.