pub type nvme_id_ns_dpc = c_uint;Expand description
enum nvme_id_ns_dpc - This field indicates the capabilities for the end-to-end data protection feature. @NVME_NS_DPC_PI_TYPE1: If set, indicates that the namespace supports Protection Information Type 1. @NVME_NS_DPC_PI_TYPE2: If set, indicates that the namespace supports Protection Information Type 2. @NVME_NS_DPC_PI_TYPE3: If set, indicates that the namespace supports Protection Information Type 3. @NVME_NS_DPC_PI_FIRST: If set, indicates that the namespace supports protection information transferred as the first eight bytes of metadata. @NVME_NS_DPC_PI_LAST: If set, indicates that the namespace supports protection information transferred as the last eight bytes of metadata.