nvme_id_ns_dps

Type Alias nvme_id_ns_dps 

pub type nvme_id_ns_dps = c_uint;
enum nvme_id_ns_dps - This field indicates the Type settings for the end-to-end data protection feature. @NVME_NS_DPS_PI_NONE: Protection information is not enabled @NVME_NS_DPS_PI_TYPE1: Protection information is enabled, Type 1 @NVME_NS_DPS_PI_TYPE2: Protection information is enabled, Type 2 @NVME_NS_DPS_PI_TYPE3: Protection information is enabled, Type 3 @NVME_NS_DPS_PI_MASK: Mask to get the value of the PI type @NVME_NS_DPS_PI_FIRST: If set, indicates that the protection information, if enabled, is transferred as the first eight bytes of metadata.