nvme_id_ns_mc

Type Alias nvme_id_ns_mc 

pub type nvme_id_ns_mc = c_uint;
enum nvme_id_ns_mc - This field indicates the capabilities for metadata. @NVME_NS_MC_EXTENDED: If set, indicates the namespace supports the metadata being transferred as part of a separate buffer that is specified in the Metadata Pointer. @NVME_NS_MC_SEPARATE: If set, indicates that the namespace supports the metadata being transferred as part of an extended data LBA.