nvme_identify_cns

Type Alias nvme_identify_cns 

pub type nvme_identify_cns = c_uint;
enum nvme_identify_cns - Identify - CNS Values @NVME_IDENTIFY_CNS_NS: Identify Namespace data structure @NVME_IDENTIFY_CNS_CTRL: Identify Controller data structure @NVME_IDENTIFY_CNS_NS_ACTIVE_LIST: Active Namespace ID list @NVME_IDENTIFY_CNS_NS_DESC_LIST: Namespace Identification Descriptor list @NVME_IDENTIFY_CNS_NVMSET_LIST: NVM Set List @NVME_IDENTIFY_CNS_CSI_NS: I/O Command Set specific Identify Namespace data structure @NVME_IDENTIFY_CNS_CSI_CTRL: I/O Command Set specific Identify Controller data structure @NVME_IDENTIFY_CNS_CSI_NS_ACTIVE_LIST: Active Namespace ID list associated with the specified I/O Command Set @NVME_IDENTIFY_CNS_CSI_INDEPENDENT_ID_NS: I/O Command Set Independent Identify @NVME_IDENTIFY_CNS_NS_USER_DATA_FORMAT: Namespace user data format @NVME_IDENTIFY_CNS_CSI_NS_USER_DATA_FORMAT: I/O Command Set specific user data format Namespace data structure @NVME_IDENTIFY_CNS_ALLOCATED_NS_LIST: Allocated Namespace ID list @NVME_IDENTIFY_CNS_ALLOCATED_NS: Identify Namespace data structure for the specified allocated NSID @NVME_IDENTIFY_CNS_NS_CTRL_LIST: Controller List of controllers attached to the specified NSID @NVME_IDENTIFY_CNS_CTRL_LIST: Controller List of controllers that exist in the NVM subsystem @NVME_IDENTIFY_CNS_PRIMARY_CTRL_CAP: Primary Controller Capabilities data structure for the specified primary controller @NVME_IDENTIFY_CNS_SECONDARY_CTRL_LIST: Secondary Controller list of controllers associated with the primary controller processing the command @NVME_IDENTIFY_CNS_NS_GRANULARITY: A Namespace Granularity List @NVME_IDENTIFY_CNS_UUID_LIST: A UUID List @NVME_IDENTIFY_CNS_DOMAIN_LIST: Domain List @NVME_IDENTIFY_CNS_ENDURANCE_GROUP_ID: Endurance Group List @NVME_IDENTIFY_CNS_CSI_ALLOCATED_NS_LIST: I/O Command Set specific Allocated Namespace ID list @NVME_IDENTIFY_CNS_CSI_ID_NS_DATA_STRUCTURE: I/O Command Set specific ID Namespace Data Structure for Allocated Namespace ID @NVME_IDENTIFY_CNS_COMMAND_SET_STRUCTURE: I/O Command Set data structure @NVME_IDENTIFY_CNS_UNDERLYING_NS_LIST: Get Underlying Namespace List @NVME_IDENTIFY_CNS_PORTS_LIST: Get Ports List @NVME_IDENTIFY_CNS_IOCS_IND_ID_ALLOC_NS: I/O Command Set Independent Identify Namespace data structure for the specified allocated NSID @NVME_IDENTIFY_CNS_SUPPORTED_CTRL_STATE_FORMATS: Supported Controller State Formats identifying the supported NVMe Controller State data structures