pub type nvme_lba_status_cmpc = c_uint;Expand description
enum nvme_lba_status_cmpc - Get LBA Status Command Completion Condition @NVME_LBA_STATUS_CMPC_NO_CMPC: No indication of the completion condition @NVME_LBA_STATUS_CMPC_INCOMPLETE: Command completed, but additional LBA Status Descriptor Entries are available to transfer or scan did not complete (if ATYPE = 10h) @NVME_LBA_STATUS_CMPC_COMPLETE: Completed the specified action over the number of LBAs specified in the Range Length field and transferred all available LBA Status Descriptors