nvme_pmrcap

Type Alias nvme_pmrcap 

pub type nvme_pmrcap = c_uint;
enum nvme_pmrcap - This field indicates the persistent memory region capabilities @NVME_PMRCAP_RDS_SHIFT: Shift amount to get the read data support @NVME_PMRCAP_WDS_SHIFT: Shift amount to get the write data support @NVME_PMRCAP_BIR_SHIFT: Shift amount to get the base indicator register @NVME_PMRCAP_PMRTU_SHIFT: Shift amount to get the persistent memory region time units @NVME_PMRCAP_PMRWBM_SHIFT: Shift amount to get the persistent memory region write barrier mechanisms @NVME_PMRCAP_PMRTO_SHIFT: Shift amount to get the persistent memory region timeout @NVME_PMRCAP_CMSS_SHIFT: Shift amount to get the controller memory space supported @NVME_PMRCAP_PMRWMB_SHIFT: Deprecated shift amount to get the persistent memory region write barrier mechanisms @NVME_PMRCAP_RDS_MASK: Mask to get the read data support @NVME_PMRCAP_WDS_MASK: Mask to get the write data support @NVME_PMRCAP_BIR_MASK: Mask to get the base indicator register @NVME_PMRCAP_PMRTU_MASK: Mask to get the persistent memory region time units @NVME_PMRCAP_PMRWBM_MASK: Mask to get the persistent memory region write barrier mechanisms @NVME_PMRCAP_PMRTO_MASK: Mask to get the persistent memory region timeout @NVME_PMRCAP_CMSS_MASK: Mask to get the controller memory space supported @NVME_PMRCAP_PMRWMB_MASK: Deprecated mask to get the persistent memory region write barrier mechanisms @NVME_PMRCAP_PMRTU_500MS: 500 milliseconds @NVME_PMRCAP_PMRTU_60S: minutes