nvme_pmrebs

Type Alias nvme_pmrebs 

pub type nvme_pmrebs = c_uint;
enum nvme_pmrebs - This field indicates the persistent memory region elasticity buffer size @NVME_PMREBS_PMRSZU_SHIFT: Shift amount to get the PMR elasticity buffer size units @NVME_PMREBS_RBB_SHIFT: Shift amount to get the read bypass behavior @NVME_PMREBS_PMRWBZ_SHIFT: Shift amount to get the PMR elasticity buffer size base @NVME_PMREBS_PMRSZU_MASK: Mask to get the PMR elasticity buffer size units @NVME_PMREBS_RBB_MASK: Mask to get the read bypass behavior @NVME_PMREBS_PMRWBZ_MASK: Mask to get the PMR elasticity buffer size base @NVME_PMREBS_PMRSZU_B: Bytes @NVME_PMREBS_PMRSZU_1K: 1 KiB @NVME_PMREBS_PMRSZU_1M: 1 MiB @NVME_PMREBS_PMRSZU_1G: 1 GiB