nvme_status_result

Type Alias nvme_status_result 

pub type nvme_status_result = c_uint;
enum nvme_status_result - Result of the device self-test operation @NVME_ST_RESULT_NO_ERR: Operation completed without error. @NVME_ST_RESULT_ABORTED: Operation was aborted by a Device Self-test command. @NVME_ST_RESULT_CLR: Operation was aborted by a Controller Level Reset. @NVME_ST_RESULT_NS_REMOVED: Operation was aborted due to a removal of a namespace from the namespace inventory. @NVME_ST_RESULT_ABORTED_FORMAT: Operation was aborted due to the processing of a Format NVM command. @NVME_ST_RESULT_FATAL_ERR: A fatal error or unknown test error occurred while the controller was executing the device self-test operation and the operation did not complete. @NVME_ST_RESULT_UNKNOWN_SEG_FAIL: Operation completed with a segment that failed and the segment that failed is not known. @NVME_ST_RESULT_KNOWN_SEG_FAIL: Operation completed with one or more failed segments and the first segment that failed is indicated in the Segment Number field. @NVME_ST_RESULT_ABORTED_UNKNOWN: Operation was aborted for unknown reason. @NVME_ST_RESULT_ABORTED_SANITIZE: Operation was aborted due to a sanitize operation. @NVME_ST_RESULT_NOT_USED: Entry not used (does not contain a test result). @NVME_ST_RESULT_MASK: Mask to get the status result value from the &struct nvme_st_result.dsts field.