nvmf_disc_eflags

Type Alias nvmf_disc_eflags 

pub type nvmf_disc_eflags = c_uint;
enum nvmf_disc_eflags - Discovery Log Page entry flags. @NVMF_DISC_EFLAGS_NONE: Indicates that none of the DUPRETINFO or EPCSD features are supported. @NVMF_DISC_EFLAGS_DUPRETINFO: Duplicate Returned Information (DUPRETINFO): Indicates that using the content of this entry to access this Discovery Service returns the same information that is returned by using the content of other entries in this log page that also have this flag set. @NVMF_DISC_EFLAGS_EPCSD: Explicit Persistent Connection Support for Discovery (EPCSD): Indicates that Explicit Persistent Connections are supported for the Discovery controller. @NVMF_DISC_EFLAGS_NCC: No CDC Connectivity (NCC): If set to ‘1’, then no DDC that describes this entry is currently connected to the CDC. If cleared to ‘0’, then at least one DDC that describes this entry is currently connected to the CDC. If the Discovery controller returning this log page is not a CDC, then this bit shall be cleared to ‘0’ and should be ignored by the host.