pub unsafe extern "C" fn nvme_directive_send(
args: *mut nvme_directive_send_args,
) -> c_intExpand description
nvme_directive_send() - Send directive command @args: &struct nvme_directive_send_args argument structure
Directives is a mechanism to enable host and NVM subsystem or controller information exchange. The Directive Send command transfers data related to a specific Directive Type from the host to the controller.
See the NVMe specification for more information.
Return: The nvme command status if a response was received (see &enum nvme_status_field) or -1 with errno set otherwise.