pub unsafe extern "C" fn nvme_dsm(args: *mut nvme_dsm_args) -> c_intExpand description
nvme_dsm() - Send an nvme data set management command @args: &struct nvme_dsm_args argument structure
The Dataset Management command is used by the host to indicate attributes for ranges of logical blocks. This includes attributes like frequency that data is read or written, access size, and other information that may be used to optimize performance and reliability, and may be used to deallocate/unmap/trim those logical blocks.
Return: The nvme command status if a response was received (see &enum nvme_status_field) or -1 with errno set otherwise.