pub unsafe extern "C" fn nvme_get_features_host_behavior(
fd: c_int,
sel: nvme_get_features_sel,
data: *mut nvme_feat_host_behavior,
result: *mut __u32,
) -> c_intExpand description
nvme_get_features_host_behavior() - Get host behavior feature @fd: File descriptor of nvme device @sel: Select which type of attribute to return, see &enum nvme_get_features_sel @data: Pointer to structure nvme_feat_host_behavior @result: The command completion result from CQE dword0
Return: The nvme command status if a response was received (see &enum nvme_status_field) or -1 with errno set otherwise.