pub unsafe extern "C" fn nvme_get_features_timestamp(
fd: c_int,
sel: nvme_get_features_sel,
ts: *mut nvme_timestamp,
) -> c_intExpand description
nvme_get_features_timestamp() - Get timestamp feature @fd: File descriptor of nvme device @sel: Select which type of attribute to return, see &enum nvme_get_features_sel @ts: Current timestamp
Return: The nvme command status if a response was received (see &enum nvme_status_field) or -1 with errno set otherwise.