pub unsafe extern "C" fn nvme_init_dsm_range(
dsm: *mut nvme_dsm_range,
ctx_attrs: *mut __u32,
llbas: *mut __u32,
slbas: *mut __u64,
nr_ranges: __u16,
)Expand description
nvme_init_dsm_range() - Constructs a data set range structure @dsm: DSM range array @ctx_attrs: Array of context attributes @llbas: Array of length in logical blocks @slbas: Array of starting logical blocks @nr_ranges: The size of the dsm arrays
Each array must be the same size of size ‘nr_ranges’. This is intended to be used with constructing a payload for nvme_dsm().
Return: The nvme command status if a response was received or -errno otherwise.