pub unsafe extern "C" fn nvme_status_to_string(
status: c_int,
fabrics: bool,
) -> *const c_charExpand description
nvme_status_to_string() - Returns string describing nvme return status. @status: Return status from an nvme passthrough command @fabrics: Set to true if &status is to a fabrics target.
Return: String representation of the nvme status if it is an nvme status field, or a standard errno string if status is < 0.