pub unsafe extern "C" fn nvmf_exat_ptr_next(
p: *mut nvmf_ext_attr,
) -> *mut nvmf_ext_attrExpand description
nvmf_exat_ptr_next - Increment @p to the next element in the array. @p: Pointer to an element of an array of “struct nvmf_ext_attr”.
Extended attributes are saved to an array of “struct nvmf_ext_attr” where each element of the array is of variable size. In order to move to the next element in the array one must increment the pointer to the current element (@p) by the size of the current element.
Return: Pointer to the next element in the array.