#[repr(C)]pub struct nvme_fabrics_config {Show 20 fields
pub host_traddr: *mut c_char,
pub host_iface: *mut c_char,
pub queue_size: c_int,
pub nr_io_queues: c_int,
pub reconnect_delay: c_int,
pub ctrl_loss_tmo: c_int,
pub fast_io_fail_tmo: c_int,
pub keep_alive_tmo: c_int,
pub nr_write_queues: c_int,
pub nr_poll_queues: c_int,
pub tos: c_int,
pub keyring: c_long,
pub tls_key: c_long,
pub tls_configured_key: c_long,
pub duplicate_connect: bool,
pub disable_sqflow: bool,
pub hdr_digest: bool,
pub data_digest: bool,
pub tls: bool,
pub concat: bool,
}Expand description
struct nvme_fabrics_config - Defines all linux nvme fabrics initiator options @host_traddr: Host transport address @host_iface: Host interface name @queue_size: Number of IO queue entries @nr_io_queues: Number of controller IO queues to establish @reconnect_delay: Time between two consecutive reconnect attempts. @ctrl_loss_tmo: Override the default controller reconnect attempt timeout in seconds @fast_io_fail_tmo: Set the fast I/O fail timeout in seconds. @keep_alive_tmo: Override the default keep-alive-timeout to this value in seconds @nr_write_queues: Number of queues to use for exclusively for writing @nr_poll_queues: Number of queues to reserve for polling completions @tos: Type of service @keyring: Keyring to store and lookup keys @tls_key: TLS PSK for the connection @tls_configured_key: TLS PSK for connect command for the connection @duplicate_connect: Allow multiple connections to the same target @disable_sqflow: Disable controller sq flow control @hdr_digest: Generate/verify header digest (TCP) @data_digest: Generate/verify data digest (TCP) @tls: Start TLS on the connection (TCP) @concat: Enable secure concatenation (TCP)
Fields
host_traddr: *mut c_charhost_iface: *mut c_charqueue_size: c_intnr_io_queues: c_intreconnect_delay: c_intctrl_loss_tmo: c_intfast_io_fail_tmo: c_intkeep_alive_tmo: c_intnr_write_queues: c_intnr_poll_queues: c_inttos: c_intkeyring: c_longtls_key: c_longtls_configured_key: c_longduplicate_connect: booldisable_sqflow: boolhdr_digest: booldata_digest: booltls: boolconcat: boolTrait Implementations
Sourceimpl Clone for nvme_fabrics_config
impl Clone for nvme_fabrics_config
Sourcefn clone(&self) -> nvme_fabrics_config
fn clone(&self) -> nvme_fabrics_config
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more