#[repr(C)]pub struct nvme_id_psd {Show 20 fields
pub mp: __le16,
pub rsvd2: __u8,
pub flags: __u8,
pub enlat: __le32,
pub exlat: __le32,
pub rrt: __u8,
pub rrl: __u8,
pub rwt: __u8,
pub rwl: __u8,
pub idlp: __le16,
pub ips: __u8,
pub rsvd19: __u8,
pub actp: __le16,
pub apws: __u8,
pub epfrt: __u8,
pub fqvt: __u8,
pub epfvt: __u8,
pub epfr_fqv_ts: __u8,
pub epfvts: __u8,
pub rsvd28: [__u8; 4],
}Expand description
struct nvme_id_psd - Power Management data structure @mp: Maximum Power indicates the sustained maximum power consumed by the NVM subsystem in this power state. The power in Watts is equal to the value in this field multiplied by the scale specified in the Max Power Scale bit (see &enum nvme_psd_flags). A value of 0 indicates Maximum Power is not reported. @rsvd2: Reserved @flags: Additional decoding flags, see &enum nvme_psd_flags. @enlat: Entry Latency indicates the maximum latency in microseconds associated with entering this power state. A value of 0 indicates Entry Latency is not reported. @exlat: Exit Latency indicates the maximum latency in microseconds associated with exiting this power state. A value of 0 indicates Exit Latency is not reported. @rrt: Relative Read Throughput indicates the read throughput rank associated with this power state relative to others. The value in this is less than the number of supported power states. @rrl: Relative Read Latency indicates the read latency rank associated with this power state relative to others. The value in this field is less than the number of supported power states. @rwt: Relative Write Throughput indicates write throughput rank associated with this power state relative to others. The value in this field is less than the number of supported power states @rwl: Relative Write Latency indicates the write latency rank associated with this power state relative to others. The value in this field is less than the number of supported power states @idlp: Idle Power indicates the typical power consumed by the NVM subsystem over 30 seconds in this power state when idle. @ips: Idle Power Scale indicates the scale for &struct nvme_id_psd.idlp, see &enum nvme_psd_ps for decoding this field. @rsvd19: Reserved @actp: Active Power indicates the largest average power consumed by the NVM subsystem over a 10 second period in this power state with the workload indicated in the Active Power Workload field. @apws: Bits 7-6: Active Power Scale(APS) indicates the scale for the &struct nvme_id_psd.actp, see &enum nvme_psd_ps for decoding this value. Bits 2-0: Active Power Workload(APW) indicates the workload used to calculate maximum power for this power state. See &enum nvme_psd_workload for decoding this field. @epfrt: Emergency power fail recovery time @fqvt: Forced quiescence vault time @epfvt: Emergency power fail vault time @epfr_fqv_ts: Bits 7-4: Forced quiescence vault time scale Bits 3-0: Emergency power fail recovery time scale @epfvts: Bits 3-0: Emergency power fail vault time scale @rsvd28: Reserved
Fields
mp: __le16rsvd2: __u8flags: __u8enlat: __le32exlat: __le32rrt: __u8rrl: __u8rwt: __u8rwl: __u8idlp: __le16ips: __u8rsvd19: __u8actp: __le16apws: __u8epfrt: __u8fqvt: __u8epfvt: __u8epfr_fqv_ts: __u8epfvts: __u8rsvd28: [__u8; 4]Trait Implementations
Sourceimpl Clone for nvme_id_psd
impl Clone for nvme_id_psd
Sourcefn clone(&self) -> nvme_id_psd
fn clone(&self) -> nvme_id_psd
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more