#[repr(C)]pub struct nvme_lm_cdq_args {
pub result: *mut __u32,
pub data: *mut c_void,
pub args_size: c_int,
pub fd: c_int,
pub timeout: __u32,
pub mos: __u16,
pub cntlid: __u16,
pub cdqid: __u16,
pub sel: __u8,
pub sz_u8: __u8,
pub rsvd1: [__u8; 4],
pub sz: __u32,
}Expand description
struct nvme_lm_cdq_args - Arguments for Controller Data Queue (CDQ) command @result: Set on completion to the command’s CQE DWORD 0 controller response @data: Pointer to data @args_size: Length of structure @fd: File descriptor of nvme device @timeout: Timeout in ms @mos: Management Operation Specific (MOS): This field is specific to the SEL type @cntlid: Controller ID: For Create CDQ, specifies the target migratable controller @cdqid: Controller Data Queue ID (CDQID): For Create CDQ, this field is the CDQID created by the controller if no error is present. For Delete CDQ, this field is the CDQID to delete. @sel: Select (SEL): This field specifies the type of management operation to perform. @sz_u8: For Create CDQ, specifies the size of CDQ, in dwords - 1 byte @rsvd1: Reserved @sz: For Create CDQ, specifies the size of CDQ, in dwords - 4 byte
Fields
result: *mut __u32data: *mut c_voidargs_size: c_intfd: c_inttimeout: __u32mos: __u16cntlid: __u16cdqid: __u16sel: __u8sz_u8: __u8rsvd1: [__u8; 4]sz: __u32Trait Implementations
Sourceimpl Clone for nvme_lm_cdq_args
impl Clone for nvme_lm_cdq_args
Sourcefn clone(&self) -> nvme_lm_cdq_args
fn clone(&self) -> nvme_lm_cdq_args
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more