#[repr(C)]pub struct nvme_nvmset_attr {
pub nvmsetid: __le16,
pub endgid: __le16,
pub rsvd4: [__u8; 4],
pub rr4kt: __le32,
pub ows: __le32,
pub tnvmsetcap: [__u8; 16],
pub unvmsetcap: [__u8; 16],
pub rsvd48: [__u8; 80],
}Expand description
struct nvme_nvmset_attr - NVM Set Attributes Entry @nvmsetid: NVM Set Identifier @endgid: Endurance Group Identifier @rsvd4: Reserved @rr4kt: Random 4 KiB Read Typical indicates the typical time to complete a 4 KiB random read in 100 nanosecond units when the NVM Set is in a Predictable Latency Mode Deterministic Window and there is 1 outstanding command per NVM Set. @ows: Optimal Write Size @tnvmsetcap: Total NVM Set Capacity @unvmsetcap: Unallocated NVM Set Capacity @rsvd48: Reserved
Fields
nvmsetid: __le16endgid: __le16rsvd4: [__u8; 4]rr4kt: __le32ows: __le32tnvmsetcap: [__u8; 16]unvmsetcap: [__u8; 16]rsvd48: [__u8; 80]Trait Implementations
Sourceimpl Clone for nvme_nvmset_attr
impl Clone for nvme_nvmset_attr
Sourcefn clone(&self) -> nvme_nvmset_attr
fn clone(&self) -> nvme_nvmset_attr
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for nvme_nvmset_attr
impl Debug for nvme_nvmset_attr
Sourceimpl Default for nvme_nvmset_attr
impl Default for nvme_nvmset_attr
impl Copy for nvme_nvmset_attr