#[repr(C)]pub struct nvme_sanitize_log_page {
pub sprog: __le16,
pub sstat: __le16,
pub scdw10: __le32,
pub eto: __le32,
pub etbe: __le32,
pub etce: __le32,
pub etond: __le32,
pub etbend: __le32,
pub etcend: __le32,
pub etpvds: __le32,
pub ssi: __u8,
pub rsvd37: [__u8; 475],
}Expand description
struct nvme_sanitize_log_page - Sanitize Status (Log Identifier 81h) @sprog: Sanitize Progress (SPROG): indicates the fraction complete of the sanitize operation. The value is a numerator of the fraction complete that has 65,536 (10000h) as its denominator. This value shall be set to FFFFh if the @sstat field is not set to %NVME_SANITIZE_SSTAT_STATUS_IN_PROGESS. @sstat: Sanitize Status (SSTAT): indicates the status associated with the most recent sanitize operation. See &enum nvme_sanitize_sstat. @scdw10: Sanitize Command Dword 10 Information (SCDW10): contains the value of the Command Dword 10 field of the Sanitize command that started the sanitize operation. @eto: Estimated Time For Overwrite: indicates the number of seconds required to complete an Overwrite sanitize operation with 16 passes in the background when the No-Deallocate Modifies Media After Sanitize field is not set to 10b. A value of 0h indicates that the sanitize operation is expected to be completed in the background when the Sanitize command that started that operation is completed. A value of FFFFFFFFh indicates that no time period is reported. @etbe: Estimated Time For Block Erase: indicates the number of seconds required to complete a Block Erase sanitize operation in the background when the No-Deallocate Modifies Media After Sanitize field is not set to 10b. A value of 0h indicates that the sanitize operation is expected to be completed in the background when the Sanitize command that started that operation is completed. A value of FFFFFFFFh indicates that no time period is reported. @etce: Estimated Time For Crypto Erase: indicates the number of seconds required to complete a Crypto Erase sanitize operation in the background when the No-Deallocate Modifies Media After Sanitize field is not set to 10b. A value of 0h indicates that the sanitize operation is expected to be completed in the background when the Sanitize command that started that operation is completed. A value of FFFFFFFFh indicates that no time period is reported. @etond: Estimated Time For Overwrite With No-Deallocate Media Modification: indicates the number of seconds required to complete an Overwrite sanitize operation and the associated additional media modification after the Overwrite sanitize operation in the background when the No-Deallocate After Sanitize bit was set to 1 in the Sanitize command that requested the Overwrite sanitize operation; and the No-Deallocate Modifies Media After Sanitize field is set to 10b. A value of 0h indicates that the sanitize operation is expected to be completed in the background when the Sanitize command that started that operation is completed. A value of FFFFFFFFh indicates that no time period is reported. @etbend: Estimated Time For Block Erase With No-Deallocate Media Modification: indicates the number of seconds required to complete a Block Erase sanitize operation and the associated additional media modification after the Block Erase sanitize operation in the background when the No-Deallocate After Sanitize bit was set to 1 in the Sanitize command that requested the Overwrite sanitize operation; and the No-Deallocate Modifies Media After Sanitize field is set to 10b. A value of 0h indicates that the sanitize operation is expected to be completed in the background when the Sanitize command that started that operation is completed. A value of FFFFFFFFh indicates that no time period is reported. @etcend: Estimated Time For Crypto Erase With No-Deallocate Media Modification: indicates the number of seconds required to complete a Crypto Erase sanitize operation and the associated additional media modification after the Crypto Erase sanitize operation in the background when the No-Deallocate After Sanitize bit was set to 1 in the Sanitize command that requested the Overwrite sanitize operation; and the No-Deallocate Modifies Media After Sanitize field is set to 10b. A value of 0h indicates that the sanitize operation is expected to be completed in the background when the Sanitize command that started that operation is completed. A value of FFFFFFFFh indicates that no time period is reported. @etpvds: Estimated Time For Post-Verification Deallocation State: indicates the number of seconds required to deallocate all media allocated for user data after exiting the Media Verification state (i.e., the time difference between entering and exiting the Post-Verification Deallocation state), if that state is entered as part of the sanitize operation. A value of FFFFFFFFh indicates that no time period is reported. @ssi: Sanitize State Information: indicate the state of the Sanitize Operation State Machine. @rsvd37: Reserved
Fields
sprog: __le16sstat: __le16scdw10: __le32eto: __le32etbe: __le32etce: __le32etond: __le32etbend: __le32etcend: __le32etpvds: __le32ssi: __u8rsvd37: [__u8; 475]Trait Implementations
Sourceimpl Clone for nvme_sanitize_log_page
impl Clone for nvme_sanitize_log_page
Sourcefn clone(&self) -> nvme_sanitize_log_page
fn clone(&self) -> nvme_sanitize_log_page
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more