#[repr(C, packed(1))]pub struct nvme_self_test_log {
pub current_operation: __u8,
pub completion: __u8,
pub rsvd: [__u8; 2],
pub result: [nvme_st_result; 20],
}Expand description
struct nvme_self_test_log - Device Self-test (Log Identifier 06h) @current_operation: Current Device Self-Test Operation: indicates the status of the current device self-test operation. If a device self-test operation is in process (i.e., this field is set to #NVME_ST_CURR_OP_SHORT or #NVME_ST_CURR_OP_EXTENDED), then the controller shall not set this field to #NVME_ST_CURR_OP_NOT_RUNNING until a new Self-test Result Data Structure is created (i.e., if a device self-test operation completes or is aborted, then the controller shall create a Self-test Result Data Structure prior to setting this field to #NVME_ST_CURR_OP_NOT_RUNNING). See &enum nvme_st_curr_op. @completion: Current Device Self-Test Completion: indicates the percentage of the device self-test operation that is complete (e.g., a value of 25 indicates that 25% of the device self-test operation is complete and 75% remains to be tested). If the @current_operation field is cleared to #NVME_ST_CURR_OP_NOT_RUNNING (indicating there is no device self-test operation in progress), then this field is ignored. @rsvd: Reserved @result: Self-test Result Data Structures, see &struct nvme_st_result.
Fields
current_operation: __u8completion: __u8rsvd: [__u8; 2]result: [nvme_st_result; 20]Trait Implementations
Sourceimpl Clone for nvme_self_test_log
impl Clone for nvme_self_test_log
Sourcefn clone(&self) -> nvme_self_test_log
fn clone(&self) -> nvme_self_test_log
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more