#[repr(C)]pub struct nvme_telemetry_log {Show 15 fields
pub lpi: __u8,
pub rsvd1: [__u8; 4],
pub ieee: [__u8; 3],
pub dalb1: __le16,
pub dalb2: __le16,
pub dalb3: __le16,
pub rsvd14: [__u8; 2],
pub dalb4: __le32,
pub rsvd20: [__u8; 360],
pub ths: __u8,
pub __bindgen_anon_1: nvme_telemetry_log__bindgen_ty_1,
pub ctrlavail: __u8,
pub ctrldgn: __u8,
pub rsnident: [__u8; 128],
pub data_area: __IncompleteArrayField<__u8>,
}Expand description
struct nvme_telemetry_log - Retrieve internal data specific to the manufacturer. @lpi: Log Identifier, either %NVME_LOG_LID_TELEMETRY_HOST or %NVME_LOG_LID_TELEMETRY_CTRL @rsvd1: Reserved @ieee: IEEE OUI Identifier is the Organization Unique Identifier (OUI) for the controller vendor that is able to interpret the data. @dalb1: Telemetry Host/Controller Initiated Data Area 1 Last Block is the value of the last block in this area. @dalb2: Telemetry Host/Controller Initiated Data Area 1 Last Block is the value of the last block in this area. @dalb3: Telemetry Host/ControllerInitiated Data Area 1 Last Block is the value of the last block in this area. @rsvd14: Reserved @dalb4: Telemetry Host/Controller Initiated Data Area 4 Last Block is the value of the last block in this area. @rsvd20: Reserved @ths: Telemetry Host-Initiated Scope @hostdgn: Telemetry Host-Initiated Data Generation Number is a value that is incremented each time the host initiates a capture of its internal controller state in the controller. @tcs: Telemetry Controller-Initiated Scope @ctrlavail: Telemetry Controller-Initiated Data Available, if cleared, then the controller telemetry log does not contain saved internal controller state. If this field is set to 1h, the controller log contains saved internal controller state. If this field is set to 1h, the data will be latched until the host releases it by reading the log with RAE cleared. @ctrldgn: Telemetry Controller-Initiated Data Generation Number is a value that is incremented each time the controller initiates a capture of its internal controller state in the controller . @rsnident: Reason Identifiers a vendor specific identifier that describes the operating conditions of the controller at the time of capture. @data_area: Telemetry data blocks, vendor specific information data.
This log consists of a header describing the log and zero or more Telemetry Data Blocks. All Telemetry Data Blocks are %NVME_LOG_TELEM_BLOCK_SIZE, 512 bytes, in size. This log captures the controller’s internal state.
Fields
lpi: __u8rsvd1: [__u8; 4]ieee: [__u8; 3]dalb1: __le16dalb2: __le16dalb3: __le16rsvd14: [__u8; 2]dalb4: __le32rsvd20: [__u8; 360]ths: __u8__bindgen_anon_1: nvme_telemetry_log__bindgen_ty_1ctrlavail: __u8ctrldgn: __u8rsnident: [__u8; 128]data_area: __IncompleteArrayField<__u8>