#[repr(C)]pub struct nvmf_die {
pub basic: __BindgenUnionField<[nvmf_disc_log_entry; 0]>,
pub extended: __BindgenUnionField<nvmf_ext_die>,
pub bindgen_union_field: [u32; 258],
}Expand description
union nvmf_die - Discovery Information Entry (DIE) @basic: Basic format (&struct nvmf_disc_log_entry) @extended: Extended format (&struct nvmf_ext_die)
Depending on the ENTFMT specified in the DIM, DIEs can be entered with the Basic or Extended formats. For Basic format, each entry has a fixed length. Therefore, the “basic” field defined below can be accessed as a C array. For the Extended format, however, each entry is of variable length (TEL). Therefore, the “extended” field defined below cannot be accessed as a C array. Instead, the “extended” field is akin to a linked-list, where one can “walk” through the list. To move to the next entry, one simply adds the current entry’s length (TEL) to the “walk” pointer. The number of entries in the list is specified by NUMENT. Although extended entries are of a variable lengths (TEL), TEL is always a multiple of 4 bytes.
Fields
basic: __BindgenUnionField<[nvmf_disc_log_entry; 0]>extended: __BindgenUnionField<nvmf_ext_die>bindgen_union_field: [u32; 258]