#[repr(C)]pub struct nvmf_disc_log_entry {Show 14 fields
pub trtype: __u8,
pub adrfam: __u8,
pub subtype: __u8,
pub treq: __u8,
pub portid: __le16,
pub cntlid: __le16,
pub asqsz: __le16,
pub eflags: __le16,
pub rsvd12: [__u8; 20],
pub trsvcid: [c_char; 32],
pub rsvd64: [__u8; 192],
pub subnqn: [c_char; 256],
pub traddr: [c_char; 256],
pub tsas: nvmf_tsas,
}Expand description
struct nvmf_disc_log_entry - Discovery Log Page entry @trtype: Transport Type (TRTYPE): Specifies the NVMe Transport type. See &enum nvmf_trtype. @adrfam: Address Family (ADRFAM): Specifies the address family. See &enum nvmf_addr_family. @subtype: Subsystem Type (SUBTYPE): Specifies the type of the NVM subsystem that is indicated in this entry. See &enum nvme_subsys_type. @treq: Transport Requirements (TREQ): Indicates requirements for the NVMe Transport. See &enum nvmf_treq. @portid: Port ID (PORTID): Specifies a particular NVM subsystem port. Different NVMe Transports or address families may utilize the same Port ID value (e.g. a Port ID may support both iWARP and RoCE). @cntlid: Controller ID (CNTLID): Specifies the controller ID. If the NVM subsystem uses a dynamic controller model, then this field shall be set to FFFFh. If the NVM subsystem uses a static controller model, then this field may be set to a specific controller ID (values 0h to FFEFh are valid). If the NVM subsystem uses a static controller model and the value indicated is FFFEh, then the host should remember the Controller ID returned as part of the Fabrics Connect command in order to re-establish an association in the future with the same controller. @asqsz: Admin Max SQ Size (ASQSZ): Specifies the maximum size of an Admin Submission Queue. This applies to all controllers in the NVM subsystem. The value shall be a minimum of 32 entries. @eflags: Entry Flags (EFLAGS): Indicates additional information related to the current entry. See &enum nvmf_disc_eflags. @rsvd12: Reserved @trsvcid: Transport Service Identifier (TRSVCID): Specifies the NVMe Transport service identifier as an ASCII string. The NVMe Transport service identifier is specified by the associated NVMe Transport binding specification. @rsvd64: Reserved @subnqn: NVM Subsystem Qualified Name (SUBNQN): NVMe Qualified Name (NQN) that uniquely identifies the NVM subsystem. For a subsystem, if that Discovery subsystem has a unique NQN (i.e., the NVM Subsystem NVMe Qualified Name (SUBNQN) field in that Discovery subsystem’s Identify Controller data structure contains a unique NQN value), then the value returned shall be that unique NQN. If the Discovery subsystem does not have a unique NQN, then the value returned shall be the well-known Discovery Service NQN (nqn.2014-08.org.nvmexpress.discovery). @traddr: Transport Address (TRADDR): Specifies the address of the NVM subsystem that may be used for a Connect command as an ASCII string. The Address Family field describes the reference for parsing this field. @tsas: Transport specific attribute settings
Fields
trtype: __u8adrfam: __u8subtype: __u8treq: __u8portid: __le16cntlid: __le16asqsz: __le16eflags: __le16rsvd12: [__u8; 20]trsvcid: [c_char; 32]rsvd64: [__u8; 192]subnqn: [c_char; 256]traddr: [c_char; 256]tsas: nvmf_tsasTrait Implementations
Sourceimpl Clone for nvmf_disc_log_entry
impl Clone for nvmf_disc_log_entry
Sourcefn clone(&self) -> nvmf_disc_log_entry
fn clone(&self) -> nvmf_disc_log_entry
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more