pub type nvme_aqa = c_uint;Expand description
enum nvme_aqa - This field indicates the admin queue attributes @NVME_AQA_ASQS_SHIFT: Shift amount to get the admin submission queue size @NVME_AQA_ACQS_SHIFT: Shift amount to get the admin completion queue size @NVME_AQA_ASQS_MASK: Mask to get the admin submission queue size @NVME_AQA_ACQS_MASK: Mask to get the admin completion queue size