pub type nvme_boot_partition_info = c_uint;Expand description
enum nvme_boot_partition_info - This field indicates the boot partition information @NVME_BOOT_PARTITION_INFO_BPSZ_SHIFT: Shift amount to get the boot partition size from the &struct nvme_boot_partition.bpinfo field. @NVME_BOOT_PARTITION_INFO_ABPID_SHIFT: Shift amount to get the active boot partition ID from the &struct nvme_boot_partition.bpinfo field. @NVME_BOOT_PARTITION_INFO_BPSZ_MASK: Mask to get the boot partition size from the &struct nvme_boot_partition.bpinfo field. @NVME_BOOT_PARTITION_INFO_ABPID_MASK: Mask to get the active boot partition ID from the &struct nvme_boot_partition.bpinfo field.