pub type nvme_bpmbl = c_uint;
enum nvme_bpmbl - This field indicates the boot partition memory buffer location @NVME_BPMBL_BMBBA_SHIFT: Shift amount to get the boot partition memory buffer base address