nvme_cmbmsc

Type Alias nvme_cmbmsc 

pub type nvme_cmbmsc = c_uint;
enum nvme_cmbmsc - This field indicates the controller memory buffer memory space control @NVME_CMBMSC_CRE_SHIFT: Shift amount to get the capabilities registers enabled @NVME_CMBMSC_CMSE_SHIFT: Shift amount to get the controller memory space enable @NVME_CMBMSC_CBA_SHIFT: Shift amount to get the controller base address @NVME_CMBMSC_CRE_MASK: Mask to get the capabilities registers enabled @NVME_CMBMSC_CMSE_MASK: Mask to get the controller memory space enable