pub type nvme_crto = c_uint;Expand description
enum nvme_crto - This field indicates the controller ready timeouts @NVME_CRTO_CRWMT_SHIFT: Shift amount to get the controller ready with media timeout @NVME_CRTO_CRIMT_SHIFT: Shift amount to get the controller ready independent of media timeout @NVME_CRTO_CRWMT_MASK: Mask to get the controller ready with media timeout @NVME_CRTO_CRIMT_MASK: Mask to get the controller ready independent of media timeout