pub type nvme_id_ctrl_hctm = c_uint;Expand description
enum nvme_id_ctrl_hctm - Flags indicate the attributes of the host controlled thermal management feature @NVME_CTRL_HCTMA_HCTM: then the controller supports host controlled thermal management, and the Set Features command and Get Features command with the Feature Identifier field set to %NVME_FEAT_FID_HCTM.