pub type nvme_id_ctrl_sqes = c_uint;Expand description
enum nvme_id_ctrl_sqes - Defines the required and maximum Submission Queue entry size when using the NVM Command Set. @NVME_CTRL_SQES_MIN: Mask to get the value of the required Submission Queue Entry size when using the NVM Command Set. @NVME_CTRL_SQES_MAX: Mask to get the value of the maximum Submission Queue entry size when using the NVM Command Set.