#[repr(C)]pub union nvmf_tsas {
pub common: [c_char; 256],
pub rdma: nvmf_tsas_rdma,
pub tcp: nvmf_tsas_tcp,
}Expand description
union nvmf_tsas - Transport Specific Address Subtype @common: Common transport specific attributes @rdma: RDMA transport specific attribute settings @qptype: RDMA QP Service Type (RDMA_QPTYPE): Specifies the type of RDMA Queue Pair. See &enum nvmf_rdma_qptype. @prtype: RDMA Provider Type (RDMA_PRTYPE): Specifies the type of RDMA provider. See &enum nvmf_rdma_prtype. @cms: RDMA Connection Management Service (RDMA_CMS): Specifies the type of RDMA IP Connection Management Service. See &enum nvmf_rdma_cms. @pkey: RDMA_PKEY: Specifies the Partition Key when AF_IB (InfiniBand) address family type is used. @tcp: TCP transport specific attribute settings @sectype: Security Type (SECTYPE): Specifies the type of security used by the NVMe/TCP port. If SECTYPE is a value of 0h (No Security), then the host shall set up a normal TCP connection. See &enum nvmf_tcp_sectype.
Fields
common: [c_char; 256]rdma: nvmf_tsas_rdmatcp: nvmf_tsas_tcp